@@ -45,6 +45,7 @@
 #include "xutil.h"
 #include "tvutil.h"
 #include "imgsav.h"
+#include "imgsav_dlg.h"
 #include "annot.h"
 #include "actions.h"
 #include "remote.h"
@@ -112,54 +113,54 @@ static struct {
     TVACTION_KEY  val;
     char         *str;
 } TVACTION_keys[] = {
-    TVA_KEY_Power,    "POWER",    
-    TVA_KEY_AllOn,    "ALLON",    
-    TVA_KEY_PC,       "PC",        
-    TVA_KEY_CD,       "CD",        
-    TVA_KEY_Web,      "WEB",       
-    TVA_KEY_DVD,      "DVD",       
-    TVA_KEY_Phone,    "PHONE",     
-    TVA_KEY_0,        "0",         
-    TVA_KEY_1,        "1",         
-    TVA_KEY_Home,     "Home",         
-    TVA_KEY_2,        "2",         
-    TVA_KEY_Up,       "Up",         
-    TVA_KEY_3,        "3",         
-    TVA_KEY_PgUp,     "PgUp",         
-    TVA_KEY_4,        "4",         
-    TVA_KEY_Left,     "Left",         
-    TVA_KEY_5,        "5",         
-    TVA_KEY_6,        "6",         
-    TVA_KEY_Right,    "Right",         
-    TVA_KEY_7,        "7",         
-    TVA_KEY_End,      "End",         
-    TVA_KEY_8,        "8",         
-    TVA_KEY_Down,     "Down",         
-    TVA_KEY_9,        "9",
-    TVA_KEY_PgDn,     "PgDn",
-    TVA_KEY_Shift,    "SHIFT",   
-    TVA_KEY_Enter,    "ENTER",     
-    TVA_KEY_VolUp,    "VOLUP",     
-    TVA_KEY_BrightUp, "BRIGHTUP",     
-    TVA_KEY_VolDn,    "VOLDN",     
-    TVA_KEY_BrightDn, "BRIGHTDN",     
-    TVA_KEY_ChanUp,   "CHANUP",    
-    TVA_KEY_On,       "ON",    
-    TVA_KEY_ChanDn,   "CHANDN",    
-    TVA_KEY_Off,      "OFF",    
-    TVA_KEY_Mute,     "MUTE",      
-    TVA_KEY_AllOff,   "ALLOFF",      
-    TVA_KEY_AB,       "A-B",        
-    TVA_KEY_Disp,     "DISP",      
-    TVA_KEY_Play,     "PLAY",      
-    TVA_KEY_Rew,      "REW",       
-    TVA_KEY_FF,       "FF",        
-    TVA_KEY_Stop,     "STOP",      
-    TVA_KEY_Rec,      "REC",       
-    TVA_KEY_Pause,    "PAUSE",     
-    TVA_KEY_Freq,     "FREQ",
-    TVA_KEY_Chan,     "CHAN",
-    TVA_KEY_Last,     "LAST"
+    { TVA_KEY_Power,    "POWER"    },
+    { TVA_KEY_AllOn,    "ALLON"    },
+    { TVA_KEY_PC,       "PC"       }, 
+    { TVA_KEY_CD,       "CD"       }, 
+    { TVA_KEY_Web,      "WEB"      }, 
+    { TVA_KEY_DVD,      "DVD"      }, 
+    { TVA_KEY_Phone,    "PHONE"    }, 
+    { TVA_KEY_0,        "0"        }, 
+    { TVA_KEY_1,        "1"        }, 
+    { TVA_KEY_Home,     "Home"     },    
+    { TVA_KEY_2,        "2"        }, 
+    { TVA_KEY_Up,       "Up"       },  
+    { TVA_KEY_3,        "3"        }, 
+    { TVA_KEY_PgUp,     "PgUp"     },    
+    { TVA_KEY_4,        "4"        }, 
+    { TVA_KEY_Left,     "Left"     },    
+    { TVA_KEY_5,        "5"        }, 
+    { TVA_KEY_6,        "6"        }, 
+    { TVA_KEY_Right,    "Right"    },     
+    { TVA_KEY_7,        "7"        }, 
+    { TVA_KEY_End,      "End"      },   
+    { TVA_KEY_8,        "8"        }, 
+    { TVA_KEY_Down,     "Down"     },    
+    { TVA_KEY_9,        "9"        },
+    { TVA_KEY_PgDn,     "PgDn"     },
+    { TVA_KEY_Shift,    "SHIFT"    },
+    { TVA_KEY_Enter,    "ENTER"    }, 
+    { TVA_KEY_VolUp,    "VOLUP"    }, 
+    { TVA_KEY_BrightUp, "BRIGHTUP" },    
+    { TVA_KEY_VolDn,    "VOLDN"    }, 
+    { TVA_KEY_BrightDn, "BRIGHTDN" },    
+    { TVA_KEY_ChanUp,   "CHANUP"   }, 
+    { TVA_KEY_On,       "ON"       },
+    { TVA_KEY_ChanDn,   "CHANDN"   }, 
+    { TVA_KEY_Off,      "OFF"      },
+    { TVA_KEY_Mute,     "MUTE"     }, 
+    { TVA_KEY_AllOff,   "ALLOFF"   },   
+    { TVA_KEY_AB,       "A-B"      },  
+    { TVA_KEY_Disp,     "DISP"     }, 
+    { TVA_KEY_Play,     "PLAY"     }, 
+    { TVA_KEY_Rew,      "REW"      }, 
+    { TVA_KEY_FF,       "FF"       }, 
+    { TVA_KEY_Stop,     "STOP"     }, 
+    { TVA_KEY_Rec,      "REC"      }, 
+    { TVA_KEY_Pause,    "PAUSE"    }, 
+    { TVA_KEY_Freq,     "FREQ"     }, 
+    { TVA_KEY_Chan,     "CHAN"     }, 
+    { TVA_KEY_Last,     "LAST"     }
 };
 
 
@@ -237,7 +238,7 @@ static void TVACTIONKeyStationEntryHdlr(
         S_chan_entry_active = TRUE;
         S_entry_freq   = do_freq;
         if ( isa_digit )
-            sprintf( S_chan_str, "%d", digit );
+            sprintf( S_chan_str, "%ld", digit );
         else if ( do_freq )
             strcpy( S_chan_str, "f" );
         else 
@@ -260,8 +261,8 @@ static void TVACTIONKeyStationEntryHdlr(
         }
     }
     else if ( (( key == TVA_KEY_KeySym ) &&
-               (( keysym >= XK_KP_Space ) && ( keysym <= XK_KP_9 ) ||
-                ( keysym >= XK_space    ) && ( keysym <= XK_asciitilde ))) 
+               ((( keysym >= XK_KP_Space ) && ( keysym <= XK_KP_9 )) ||
+                (( keysym >= XK_space    ) && ( keysym <= XK_asciitilde )))) 
               ||
               isa_digit ) {
 
@@ -344,7 +345,7 @@ void TVACTIONKeyEventHdlr(
 
     if ( strncmp( str, "KEYSYM", 6 ) == 0 ) {
         key    = TVA_KEY_KeySym;
-        sscanf( str+6, "%d,%s", &keysym, keysym_buf );
+        sscanf( str+6, "%ld,%s", &keysym, keysym_buf );
     }
     else {
         for ( i = 0; i < XtNumber( TVACTION_keys ); i++ )
@@ -386,41 +387,8 @@ void TVACTIONKeyEventHdlr(
             action  = "TVToggleMute";
             break;
 
-#ifdef OLD
-        case TVA_KEY_Power :
-        case TVA_KEY_AllOn :
-        case TVA_KEY_PC :
-        case TVA_KEY_CD :
-        case TVA_KEY_Web :
-        case TVA_KEY_DVD :
-        case TVA_KEY_Phone :
-        case TVA_KEY_Home :
-        case TVA_KEY_Up :
-        case TVA_KEY_PgUp :
-        case TVA_KEY_Left :
-        case TVA_KEY_Right :
-        case TVA_KEY_End :
-        case TVA_KEY_Down :
-        case TVA_KEY_PgDn :
-        case TVA_KEY_Shift :
-        case TVA_KEY_Enter :
-        case TVA_KEY_BrightUp :
-        case TVA_KEY_BrightDn :
-        case TVA_KEY_On :
-        case TVA_KEY_Off :
-        case TVA_KEY_AllOff :
-        case TVA_KEY_AB :
-        case TVA_KEY_Disp :
-        case TVA_KEY_Play :
-        case TVA_KEY_Rew :
-        case TVA_KEY_FF :
-        case TVA_KEY_Stop :
-        case TVA_KEY_Rec :
-        case TVA_KEY_Pause :
-        case TVA_KEY_Freq :
-        case TVA_KEY_Chan :
-        case TVA_KEY_Last : 
-#endif
+        default :
+            break;
     }
     
     if ( action ) {
@@ -499,18 +467,18 @@ void TVACTIONVideoWinEventHdlr(
             if (( keysym == XK_KP_Enter ) || ( keysym == XK_Linefeed ))
                 keysym = XK_Return;
             if ( keysym == XK_Delete )
-                keysym == XK_BackSpace;
+                keysym = XK_BackSpace;
 
             /*  Don't pass anything but the Return/BS & printable chars  */
             if (( keysym != XK_Return ) && ( keysym != XK_BackSpace ) &&
-                !(( keysym >= XK_KP_Space ) && ( keysym <= XK_KP_9 ) ||
-                  ( keysym >= XK_space    ) && ( keysym <= XK_asciitilde ))) {
+                !((( keysym >= XK_KP_Space ) && ( keysym <= XK_KP_9 )) ||
+                  (( keysym >= XK_space    ) && ( keysym <= XK_asciitilde )))){
                 S_chan_entry_active = FALSE;
                 TVTOOLSResync();
                 break;
             }
 
-            sprintf( key_str, "KEYSYM%d,%s", keysym, key_buf );
+            sprintf( key_str, "KEYSYM%ld,%s", keysym, key_buf );
             TVACTIONKeyEventHdlr( key_str, &handled );
             
             *continue_dispatch = !handled;
@@ -560,8 +528,8 @@ static void TVActionSetStationAction(
                      num_chan;
     TV_STATION      *channel;
     TV_INT8          chan_inc = 0,
-                     freq_inc = 0,
-                     chan_num = -1;
+                     freq_inc = 0;
+    TV_INT32         chan_num = -1;
     float            chan_freq;
     TV_BOOL          valid;
     char            *str = NULL;
@@ -615,11 +583,10 @@ static void TVActionSetStationAction(
 
         chan_id[0] = '\0';
         strncat( chan_id, str, sizeof(chan_id)-1 );
-        TVUTILstrupr( chan_id );
 
         /*  1st, look for a predefined station with a matching identifier  */
         for ( i = 0; i < num_chan; i++ )
-            if ( strcmp( chan_id, channel[i].id ) == 0 ) {
+            if ( strcasecmp( chan_id, channel[i].id ) == 0 ) {
                 if ( channel[ i ].set_via_channel )
                     chan_num  = channel[ i ].channel;   
                 else
@@ -633,7 +600,7 @@ static void TVActionSetStationAction(
             if (( sscanf( str, "f%f", &chan_freq ) == 1 ) ||
                 ( sscanf( str, "F%f", &chan_freq ) == 1 )) 
                 chan_num  = -1;
-            else if (( sscanf( str, "%d", &chan_num ) == 1 ) &&
+            else if (( sscanf( str, "%ld", &chan_num ) == 1 ) &&
                      ( chan_num >= TV_CHAN_MIN ))
                 chan_freq = 0.0;
             else {
@@ -741,7 +708,7 @@ static void TVActionToggleZoomAction(
 {
     TV_DISPLAY        *d = &G_glob.display;
     TV_BOOL            valid,
-                       fullscreen;
+                       fullscreen = False;
     char               arg[80];
 
     /*  Verify and extract argument ("window" or "fullscreen") */
@@ -846,7 +813,7 @@ static void TVActionSetVolumeAction(
     vol_val = MAX( TV_VOLUME_MIN, MIN( TV_VOLUME_MAX, vol_val ) );
 
     /*  Bump volume, and update GUI  */
-    TVAUDIOSetLineVolume( vol_val, True );
+    TVAUDIOSetLineVolume( vol_val, TRUE );
     TVANNOTSignalPropChange( &d->annot, TV_ANNOT_TYPE_VOLUME );
 }
 
@@ -1173,7 +1140,7 @@ static void TVActionSaveImageAction(
         else
             len = p - dsk->fn_freeze_base;
 
-        sprintf( fname, "%.*s%.3d%s", len, dsk->fn_freeze_base, 
+        sprintf( fname, "%.*s%.3ld%s", (int)len, dsk->fn_freeze_base, 
                         dsk->freeze_next_suffix, (p ? p : "") );
     }
     else
@@ -1252,6 +1219,44 @@ static void TVActionToggleFreezeAction(
 }
 
 
+/**@BEGINFUNC**************************************************************
+
+    Prototype  : static void TVActionQuitAction(
+                      Widget    wgt,
+                      XEvent   *xevent,
+                      String   *params,
+                      Cardinal *num_params )
+
+    Purpose    : Action to toggle the freeze state on and off.
+
+    Programmer : 12-Apr-97  Randall Hopper
+
+    Parameters : wgt        - I: <not used>
+                 xevent     - I: <not used>
+                 params     - I: <not used>
+                 num_params - I: should be 0
+
+    Returns    :
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+static void TVActionQuitAction(
+                Widget    wgt,
+                XEvent   *xevent,
+                String   *params,
+                Cardinal *num_params )
+{
+    if ( *num_params > 0 ) {
+        fprintf( stderr, 
+              "TVActionQuitAction: Unexpected argument ignored.\n" );
+    }
+
+    exit(0);
+}
+
+
 /**@BEGINFUNC**************************************************************
 
     Prototype  : static void TVActionVideoRecordStartAction(
@@ -1282,7 +1287,6 @@ static void TVActionVideoRecordStartAction(
                 String   *params,
                 Cardinal *num_params )
 {
-    TV_DISPLAY        *d = &G_glob.display;
     TV_INT32           w,h;
 
     if (( *num_params > 1 )) {
@@ -1291,7 +1295,7 @@ static void TVActionVideoRecordStartAction(
     }
 
     if (( *num_params == 1 ) && params[0] ) {
-        if (( sscanf( params[0], "%dx%d", &w, &h ) != 2 ) ||
+        if (( sscanf( params[0], "%ldx%ld", &w, &h ) != 2 ) ||
             ( w <= 0 ) || ( h <= 0 )) {
             fprintf( stderr, 
                 "TVActionVideoRecordStartAction:  Bad resolution.\n" );
@@ -1334,8 +1338,6 @@ static void TVActionVideoRecordStopAction(
                 String   *params,
                 Cardinal *num_params )
 {
-    TV_DISPLAY        *d = &G_glob.display;
-
     if ( *num_params > 0 ) {
         fprintf( stderr, 
             "TVActionVideoRecordStopAction: Unexpected argument ignored.\n" );
@@ -1344,6 +1346,17 @@ static void TVActionVideoRecordStopAction(
     TVVIDSAVDIALOGRecordStop();
 }
 
+static void TVActionNoOp( 
+                Widget    wgt,
+                XEvent   *xevent,
+                String   *params,
+                Cardinal *num_params )
+{
+  /*
+   * This one doesn't deserve a header.  It's a no-op action routine.
+   */
+}
+
 
 /**@BEGINFUNC**************************************************************
 
@@ -1402,7 +1415,7 @@ void TVActionSetVolume( TV_INT32 vol )
     String   param[1] = { str };
     Cardinal num_param = 1;
 
-    sprintf( str, "%d", vol );
+    sprintf( str, "%ld", vol );
     TVActionSetVolumeAction( NULL, NULL, param, &num_param );
 }
 
@@ -1412,7 +1425,7 @@ void TVActionSetVolumeRel( TV_INT32 vol_delta )
     String   param[1] = { str };
     Cardinal num_param = 1;
 
-    sprintf( str, "%+d", vol_delta );
+    sprintf( str, "%+ld", vol_delta );
     TVActionSetVolumeAction( NULL, NULL, param, &num_param );
 }
 
@@ -1442,7 +1455,7 @@ void TVActionSetCaptureInputRel( TV_INT32 dev_delta )
     String   param[1] = { str };
     Cardinal num_param = 1;
 
-    sprintf( str, "%+d", dev_delta );
+    sprintf( str, "%+ld", dev_delta );
     TVActionSetCaptureInputAction( NULL, NULL, param, &num_param );
 }
 
@@ -1459,6 +1472,11 @@ void TVActionToggleFreeze( void )
     TVActionToggleFreezeAction( NULL, NULL, NULL, &num_param );
 }
 
+void TVActionQuit( void )
+{
+    Cardinal num_param = 0;
+    TVActionQuitAction( NULL, NULL, NULL, &num_param );
+}
 
 /**@BEGINFUNC**************************************************************
 
@@ -1488,7 +1506,9 @@ void TVActionAddAppActions()
          { "TVSaveImage"        , TVActionSaveImageAction         },
          { "TVToggleFreeze"     , TVActionToggleFreezeAction      },
          { "TVVideoRecordStart" , TVActionVideoRecordStartAction  },
-         { "TVVideoRecordStop"  , TVActionVideoRecordStopAction   }
+         { "TVVideoRecordStop"  , TVActionVideoRecordStopAction   },
+         { "TVQuit"             , TVActionQuitAction              },
+         { "no-op"              , TVActionNoOp                    }
         };
 
     XtAppAddActions( TVAPPCTX, (XtActionsRec *) S_actions, 
