@@ -48,7 +48,8 @@ typedef struct _AppResources {
     int      device_number;
     String   input_format;
     String   tuner_mode;
-    int      def_chan;
+
+    String   def_chan;
     String   def_input;
     String   def_audio_input;
     int      display_fps;
@@ -106,6 +107,9 @@ typedef struct _AppResources {
     Pixel    mute_annot_color;
     int      mute_annot_delay;
 
+    Boolean  station_in_win_title;
+    Boolean  station_in_win_icon;
+
     Boolean  help;
 
 } AppResources;
@@ -223,6 +227,11 @@ extern AppResources     App_res;
 #define RNmuteAnnotColor       "muteAnnotColor"
 #define RNmuteAnnotDelay       "muteAnnotDelay"
 
+#define RNstationInWinTitle    "stationInWinTitle"
+#define RCstationInWinTitle    "StationInWinTitle"
+
+#define RNstationInWinIcon     "stationInWinIcon"
+#define RCstationInWinIcon     "StationInWinIcon"
 
 AppResources     App_res;
 
@@ -301,6 +310,11 @@ static XrmOptionDescRec Cmd_line_options[] = {
    { "-muteAnnotColor"     , RNmuteAnnotColor     , XrmoptionSepArg, NULL    },
    { "-muteAnnotDelay"     , RNmuteAnnotDelay     , XrmoptionSepArg, NULL    },
 
+   { "-remoteType"         , RNremoteType     , XrmoptionSepArg, NULL        },
+
+   { "-stationInWinTitle"  , RNstationInWinTitle  , XrmoptionNoArg , pTRUE   },
+   { "-stationInWinIcon"   , RNstationInWinIcon   , XrmoptionNoArg , pTRUE   },
+
    { "-help"          , RNhelp           , XrmoptionNoArg , (caddr_t) "True"  },
 #ifdef DEBUG
    { "-fps"           , RNfps            , XrmoptionSepArg, NULL              },
@@ -341,8 +355,8 @@ static XtResource Resources[] = {
     { RNtunerMode, RCtunerMode, XtRString, sizeof(String),
         XtOffsetOf(AppResources, tuner_mode      ), XtRImmediate,
         "antenna" },
-    { RNdefaultChannel, RCdefaultChannel, XtRInt, sizeof(int),
-        XtOffsetOf(AppResources, def_chan), XtRString,
+    { RNdefaultChannel, RCdefaultChannel, XtRString, sizeof(String),
+        XtOffsetOf(AppResources, def_chan), XtRImmediate,
         "0" /*  0 = Don't change channel */ },   
     { RNdefaultInput, RCdefaultInput, XtRString, sizeof(String),
         XtOffsetOf(AppResources, def_input), XtRImmediate,
@@ -431,6 +445,13 @@ static XtResource Resources[] = {
         XtOffsetOf(AppResources, remote_type ), XtRImmediate, 
         "None"  },
 
+    { RNstationInWinTitle, RCstationInWinTitle, XtRBoolean, sizeof(Boolean),
+        XtOffsetOf(AppResources, station_in_win_title), XtRImmediate,
+        (XtPointer) False },
+    { RNstationInWinIcon, RCstationInWinIcon, XtRBoolean, sizeof(Boolean),
+        XtOffsetOf(AppResources, station_in_win_icon), XtRImmediate,
+        (XtPointer) False },
+
     { RNvideoCapFile1, RCvideoCapFile, XtRString, sizeof(String),
         XtOffsetOf(AppResources, video_cap_file[0] ), XtRImmediate, 
         ""  },
@@ -531,19 +552,22 @@ Available options:
 -defaultInput <input>       - Startup tuner signal input 
                                  [tuner|video|svideo|csvideo]
 -defaultAudioInput <input>  - Startup TV card audio input 
-                                 [tuner|external|internal]
+                                 [tuner|external|internal|auto]
 -defaultChannel <#>         - Startup Channel Number
 -cableStationList   <...>   - List of cable station presets (see rsrc file)
 -antennaStationList <...>   - List of antenna station presets
 -cableFreqSet   <freqset>   - Freq set for cable   (def = cableirc)
                               [nabcst|cableirc|cablehrc|weurope|jpnbcst|
-                               jpncable|xussr]
+                               jpncable|xussr|australia]
 -antennaFreqSet <freqset>   - Freq set for antenna (def = nabcst)
 
 -noAudio                    - Suppress playing audio through soundcard
 -dspDevice                  - Override default DSP device   (def=/dev/dsp)
 -mixerDevice                - Override default mixer device (def=/dev/mixer)
--mixerChannel               - Specify mixer channel (line,cd)
+-mixerChannel               - Specify mixer channel (line,cd,mic)
+
+-stationInWinTitle          - Display station text in window title
+-stationInWinIcon           - Display station text in window icon
 
 -stationAnnotFont <fontpat> - Font pattern for station annot (see rsrc file)
 -stationAnnotColor <color>  - Color for station annot
@@ -556,7 +580,8 @@ Available options:
 -muteDevAnnot{Font,Color,Delay}
                             - Other annotation options (see stationAnnot)
 
--remoteType                 - Type of attached remote control (None,X10)
+-remoteType                 - Type of attached remote control 
+                              [None|X10|Hauppauge|PixelView]
 
 -recCmdMpeg2                - MPEG-2 Audio record command 
 -recCmdMpeg3                - MPEG-3 Audio record command
@@ -684,6 +709,8 @@ static String fallback_resources[] = {
    "*toolBox*volumeForm.horizDistance:        0",
    "*toolBox*volumeScrollbar.width:           75",
    "*toolBox*volumeScrollbar.height:          15",
+   "*toolBox*SimpleMenu*Cursor:               hand2",
+   "*toolBox*SimpleMenu*HorizontalMargins:    20",
 
    /*  Video window appearance */
    "*videoWin*background:                     Black",
@@ -742,7 +769,7 @@ static String fallback_resources[] = {
    "*imageSaveDialog*Text*background:              Gray60",
    "*imageSaveDialog*Text*foreground:              Black",
    "*imageSaveDialog*Text.borderWidth:             1",
-   "*imageSaveDialog*Text.width:                   150",
+   "*imageSaveDialog*Text.width:                   300",
    "*imageSaveDialog*Toggle.width:                 16",
    "*imageSaveDialog*Toggle.height:                16",
    "*imageSaveDialog*Toggle.horizDistance:         40",
