@@ -39,6 +39,7 @@
 #include <unistd.h>
 #include <X11/Intrinsic.h>
 #include "tvdefines.h"
+#include "tvutil.h"
 #include "rawvideo.h"
 
 /*      ******************** Local defines                ************** */
@@ -94,6 +95,13 @@ TV_UINT32 TVRAWVIDEOCalcImageSize(
                    ( pg->samp_size[2] == 8 ));
 
             /* FIXME:  What if X/Y res isn't a multiple of sampling rate?  */
+            printf( "num_pix = %ld\n"
+                    "pg->samp_int_h = %ld,%ld , %ld,%ld , %ld,%ld\n",
+                    num_pix,
+                    pg->samp_int_h[0], pg->samp_int_v[0],
+                    pg->samp_int_h[1], pg->samp_int_v[1],
+                    pg->samp_int_h[2], pg->samp_int_v[2] );
+
             return num_pix / (pg->samp_int_h[0] * pg->samp_int_v[0]) +
                    num_pix / (pg->samp_int_h[1] * pg->samp_int_v[1]) +
                    num_pix / (pg->samp_int_h[2] * pg->samp_int_v[2]);
@@ -152,9 +160,9 @@ TV_BOOL TVRAWVIDEOOpen( char               *filenames[],
 
     /*  Open files  */
     if ( read )
-        flags = O_RDONLY        , mode = 0;
+        flags = O_RDONLY                , mode = 0;
     else 
-        flags = O_CREAT|O_WRONLY, mode = 0666;        
+        flags = O_CREAT|O_WRONLY|O_TRUNC, mode = 0666;        
 
     for ( i = 0; i < num_files; i++ ) {
         strncat( raw_f->fname[i], filenames[i], sizeof( raw_f->fname[i] )-1 );
@@ -218,6 +226,8 @@ TV_BOOL TVRAWVIDEOClose( TV_RAW_VIDEO_FILE **rf )
         close( (*rf)->fd[i] );
     free( *rf );
     *rf = NULL;
+
+    return TRUE;
 }
 
 
