@@ -3,6 +3,10 @@
  *
  * Module for handling remote controls supported by FXTV.
  *
+ * NOTE: For legacy reasons, this module contains both the remote-generic
+ * routines (TVREMOTE*, etc.) as well as the X10 Remote-specific code
+ * (TVX10REMOTE*, etc.).  FIXME: We should break these out at some point.
+ *
  * (C) 1998 Randall Hopper
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +38,9 @@
 #include <errno.h>
 #include <string.h>
 #include <fcntl.h>
+#include <sys/types.h>
+#include <sys/uio.h>
+#include <unistd.h>
 #include <termios.h>
 #include <sys/time.h>
 #include <sys/socket.h>
@@ -41,18 +48,23 @@
 #include <machine/mouse.h>
 #include <X11/Intrinsic.h>
 #include "tvdebug.h"
+#include "tvutil.h"
 #include "remote.h"
+#include "haup_remote.h"
+#include "pixelview_remote.h"
 
 /*      ******************** Local defines                ************** */
 
+#ifndef __NetBSD__
+
 /*  FIXME: Remove this old code someday  */
-#ifndef _PATH_MOUSEREMOTE
+#ifdef 0
 #  define OLD_DEV_SYSMOUSE_STUFF
 #endif
 
 /*  This is an easy way to keep fxtv buildable on FreeBSD versions that  */
 /*    have "old" versions of the moused/syscons stuff -- e.g. 2.2.1      */
-#ifndef MOUSE_SYS_PACKETSIZE
+#if !defined(MOUSE_SYS_PACKETSIZE) || !defined(_PATH_MOUSEREMOTE)
 #  undef  OLD_DEV_SYSMOUSE_STUFF
 #  define _PATH_MOUSEREMOTE "foo"
 #endif
@@ -66,15 +78,23 @@
 
 #define X10_KEY_SHIFT  0x6b
 
+typedef enum { REMOTE_TYPE_X10, REMOTE_TYPE_HAUPPAUGE,
+               REMOTE_TYPE_PIXELVIEW } REMOTE_TYPE;
+
 /*      ******************** Private variables            ************** */
 
+static REMOTE_TYPE        Remote_type = -1;
+
 static int                Remote_fd       = -1;
 static XtInputId          Remote_input_id;
 static TVREMOTE_CB_FUNCT *Remote_cb       = NULL;
+
+#ifdef OLD_DEV_SYSMOUSE_STUFF
 static struct termios     Save_term_attr;
 static int                Save_modem_attr;
 static unsigned char      Events[ MOUSE_SYS_PACKETSIZE * 50 ];
 ssize_t                   Events_len = 0;
+#endif
 
 static struct {
     char          *name;
@@ -348,7 +368,7 @@ static void ProcessMouseRemoteKey(
 
     /*  Debounce the key and get shift state  */
     if ( !DebounceAndGetShift( btn, &shift ) ) {
-        RMPRINTF(( "TVREMOTE:  Event debounced (ignored)\n" ));
+        RMPRINTF(( "TVX10REMOTE:  Event debounced (ignored)\n" ));
         return;
     }
 
@@ -359,14 +379,14 @@ static void ProcessMouseRemoteKey(
             break;
 
     if ( j < ARRAY_SIZ(X10_keys) ) {
-        RMPRINTF(( "TVREMOTE:  KEY EVENT = <%s>\n", 
+        RMPRINTF(( "TVX10REMOTE:  KEY EVENT = <%s> %s\n", 
                    X10_keys[j].name,
                    (shift ? "(SHIFTED)" : "") ));
         if ( Remote_cb )
             Remote_cb( X10_keys[j].name );
     }
     else
-        RMPRINTF(( "TVREMOTE:  Unknown key event...skipped\n" ));
+        RMPRINTF(( "TVX10REMOTE:  Unknown key event...skipped\n" ));
 }
 
                  
@@ -374,7 +394,7 @@ static void ProcessMouseRemoteKey(
 
 /**@BEGINFUNC**************************************************************
 
-    Prototype  : static void TVRemoteInputProcSysMouse(
+    Prototype  : static void TVX10RemoteInputProcSysMouse(
                       XtPointer  cb_data,
                       int       *fd,
                       XtInputId *id )
@@ -394,7 +414,7 @@ static void ProcessMouseRemoteKey(
 
  **@ENDFUNC*****************************************************************/
 
-static void TVRemoteInputProcSysMouse( 
+static void TVX10RemoteInputProcSysMouse( 
                 XtPointer  cb_data,
                 int       *fd,
                 XtInputId *id )
@@ -410,12 +430,12 @@ static void TVRemoteInputProcSysMouse(
         len = read( *fd, buf, sizeof(buf) );
         if ( len <= 0 )
             return;
-        RMPRINTF(( "TVREMOTE:  Got %d new bytes\n", len ));
+        RMPRINTF(( "TVX10REMOTE:  Got %d new bytes\n", len ));
 
         /*  Tack new data onto queue  */
         if ( Events_len + len > sizeof(Events) ) {
             fprintf( stderr,
-                     "TVRemoteInputProc: Buffer overflow...resetting\n" );
+                     "TVX10RemoteInputProc: Buffer overflow...resetting\n" );
             Events_len = 0;
             return;
         }
@@ -427,7 +447,7 @@ static void TVRemoteInputProcSysMouse(
 
             /*  Skip to beginning of next event sequence  */
             if ( (Events[i] & MOUSE_SYS_SYNCMASK) != MOUSE_SYS_SYNC ) {
-                RMPRINTF(( "TVREMOTE:  Discarded: %.2x\n", Events[i] ));
+                RMPRINTF(( "TVX10REMOTE:  Discarded: %.2x\n", Events[i] ));
                 i++;
                 continue;
             }
@@ -437,7 +457,7 @@ static void TVRemoteInputProcSysMouse(
                 break;
 
             /*  Print event  */
-            RMPRINTF(( "%30cTVREMOTE EVENT = ", ' ' ));
+            RMPRINTF(( "%30cTVX10REMOTE EVENT = ", ' ' ));
             for ( j = 0; j < MOUSE_SYS_PACKETSIZE; j++ )
                 RMPRINTF(( "%.2x ", buf[i+j] ));
             RMPRINTF(( "\n" ));
@@ -446,7 +466,7 @@ static void TVRemoteInputProcSysMouse(
             /*    skip it                                               */
             if ( (Events[i+5] | Events[i+6]) == 0 ) {
                 i += MOUSE_SYS_PACKETSIZE;
-                RMPRINTF(( "TVREMOTE:  Event ignored\n" ));
+                RMPRINTF(( "TVX10REMOTE:  Event ignored\n" ));
                 continue;
             }
 
@@ -478,7 +498,7 @@ static void TVRemoteInputProcSysMouse(
 
 /**@BEGINFUNC**************************************************************
 
-    Prototype  : static void TVRemoteInputProcMouseRemSocket(
+    Prototype  : static void TVX10RemoteInputProcMouseRemSocket(
                       XtPointer  cb_data,
                       int       *fd,
                       XtInputId *id )
@@ -498,7 +518,7 @@ static void TVRemoteInputProcSysMouse(
 
  **@ENDFUNC*****************************************************************/
 
-static void TVRemoteInputProcMouseRemSocket( 
+static void TVX10RemoteInputProcMouseRemSocket( 
                 XtPointer  cb_data,
                 int       *fd,
                 XtInputId *id )
@@ -513,7 +533,7 @@ static void TVRemoteInputProcMouseRemSocket(
             break;
 
         /*  And process */
-        RMPRINTF(( "TVREMOTE:  Got a btn: %d\n", btn ));
+        RMPRINTF(( "TVX10REMOTE:  Got a btn: %d\n", btn ));
         ProcessMouseRemoteKey( btn );
     }
 }
@@ -523,7 +543,7 @@ static void TVRemoteInputProcMouseRemSocket(
 
 /**@BEGINFUNC**************************************************************
 
-    Prototype  : static void TVREMOTEClose(
+    Prototype  : static void TVX10REMOTEClose(
                       void )
 
     Purpose    : Called when we're exiting the program to cleanup and
@@ -539,7 +559,7 @@ static void TVRemoteInputProcMouseRemSocket(
 
  **@ENDFUNC*****************************************************************/
 
-static void TVREMOTEClose( void )
+static void TVX10REMOTEClose( void )
 {
     /*  Do nothing if we didn't open the remote  */
     if ( Remote_fd < 0 )
@@ -559,15 +579,16 @@ static void TVREMOTEClose( void )
     Remote_fd = -1;
 }
 
+#endif	/* !__NetBSD__ */
+
 
 /**@BEGINFUNC**************************************************************
 
-    Prototype  : void TVREMOTEOpen(
+    Prototype  : void TVX10REMOTEOpen(
                       XtAppContext       app_ctx,
-                      char               rem_type[],
                       TVREMOTE_CB_FUNCT *cb )
 
-    Purpose    : Open procedure for the mouse remote device.
+    Purpose    : Open procedure for the X10 mouse remote device.
 
                  If we can't open the device (permissions, etc.), we
                  just return without doing anything.  For other errors
@@ -585,26 +606,18 @@ static void TVREMOTEClose( void )
 
  **@ENDFUNC*****************************************************************/
 
-void TVREMOTEOpen( XtAppContext       app_ctx, 
-                   char               rem_type[], 
-                   TVREMOTE_CB_FUNCT *cb )
+void TVX10REMOTEOpen( XtAppContext       app_ctx, 
+                      TVREMOTE_CB_FUNCT *cb )
 {
+#ifndef __NetBSD__
     int                fd,
-                       flags,
-                       level;
-    char               type_str[20];
+                       flags;
+#ifdef OLD_DEV_SYSMOUSE_STUFF
     mousemode_t        mouse_mode;
-	struct sockaddr_un remsrv_addr;
+    int                level;
+#endif
+    struct sockaddr_un remsrv_addr;
 
-    /*  Sanity check remote type  */
-    type_str[0] = '\0';
-    strncat( type_str, rem_type, sizeof(type_str)-1 );
-    TVUTILstrupr( type_str );
-    if ( strcmp( type_str, "X10" ) != 0 ) {
-        fprintf( stderr, "TVREMOTEOpen: Only X10 remotes are supported.\n" );
-        exit(1);
-    }
-    
 #ifdef OLD_DEV_SYSMOUSE_STUFF
     /*  Open device  */
     fd = Remote_fd = open( rem_dev, O_RDWR | O_NONBLOCK, 0 );
@@ -615,7 +628,7 @@ void TVREMOTEOpen( XtAppContext       app_ctx,
         return;
     }
 
-    RMPRINTF(( "TVREMOTE:  Device open.\n" ));
+    RMPRINTF(( "TVX10REMOTE:  Device open.\n" ));
 
     /*  Save device state  */
     tcgetattr( fd, &Save_term_attr );
@@ -677,20 +690,128 @@ void TVREMOTEOpen( XtAppContext       app_ctx,
 
     /*  Register filedesc activity proc with dispatch procedure  */
     Remote_input_id = XtAppAddInput( app_ctx, fd, 
-                                     (XtPointer) XtInputReadMask,
+                                  (XtPointer) XtInputReadMask,
 #ifdef OLD_DEV_SYSMOUSE_STUFF
-                                     TVRemoteInputProcSysMouse, NULL );
+                                  TVX10RemoteInputProcSysMouse, NULL );
 #else
-                                     TVRemoteInputProcMouseRemSocket, NULL );
+                                  TVX10RemoteInputProcMouseRemSocket, NULL );
 #endif
 
-    RMPRINTF(( "TVREMOTE:  Device configured and ready.\n" ));
+    RMPRINTF(( "TVX10REMOTE:  Device configured and ready.\n" ));
 
     /*  Store off callback function  */
     Remote_cb = cb;
 
     /*  Arrange to get called when we exit the app  */
-    atexit( TVREMOTEClose );
+    atexit( TVX10REMOTEClose );
+#endif	/* !__NetBSD__ */
+}
+
+
+/**@BEGINFUNC**************************************************************
+
+    Prototype  : void TVX10REMOTEFlush(
+                      void )
+
+    Purpose    : Flush any stray input from the remote.  
+
+                 Why do we have this?  Sometimes we need to perform an
+                 operation that takes a while (e.g. switching video modes)
+                 which may have been instigated by a remote event.  
+                 This messes up the debouncing we do for the remote.
+                 So we flush the events after we perform the long operation.
+
+    Programmer : 31-May-98  Randall Hopper
+
+    Parameters : void 
+
+    Returns    : void
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+void TVX10REMOTEFlush( void )
+{
+#ifndef __NetBSD__
+    unsigned char  btn;
+
+    /*  Do nothing if we didn't open the remote  */
+    if ( Remote_fd < 0 )
+        return;
+
+    /*  Loop while still data  */
+    while (1) {
+
+        /*  Grab a key (until buffer empty)  */
+        if ( read( Remote_fd, &btn, 1 ) <= 0 )
+            break;
+        RMPRINTF(( "TVX10REMOTE:  Flushing buffer (key = %d)\n", btn ));
+    }
+#endif	/* !__NetBSD__ */
+}
+
+
+/*---------------------------------------------------------------------------*/
+/*------------  Hereafter lies the "generic" remote routines  ---------------*/
+/*---------------------------------------------------------------------------*/
+
+
+/**@BEGINFUNC**************************************************************
+
+    Prototype  : void TVREMOTEOpen(
+                      XtAppContext       app_ctx,
+                      char               rem_type[],
+                      TVREMOTE_CB_FUNCT *cb )
+
+    Purpose    : Open procedure for the mouse remote device.
+
+                 If we can't open the device (permissions, etc.), we
+                 just return without doing anything.  For other errors
+                 we bail out of the program.
+
+    Programmer : 17-May-98  Randall Hopper
+
+    Parameters : app_ctx   - I: Xt app context (used to register fd callback)
+                 rem_type  - I: type of remote (e.g. X10, Hauppauge, etc.)
+                 cb        - I: funct to call to process key events
+
+    Returns    : None.
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+void TVREMOTEOpen( XtAppContext       app_ctx, 
+                   char               rem_type[], 
+                   TVREMOTE_CB_FUNCT *cb )
+{
+    char type_str[20];
+
+    /*  Branch to the appropriate Open method based on remote type.  */
+    /*    If invalid, error message and bail out of the program.     */
+    type_str[0] = '\0';
+    strncat( type_str, rem_type, sizeof(type_str)-1 );
+    TVUTILstrupr( type_str );
+
+    if ( STREQ( type_str, "X10" ) ) {
+        TVX10REMOTEOpen ( app_ctx, cb );
+        Remote_type = REMOTE_TYPE_X10;
+    }
+    else if ( STREQ( type_str, "HAUPPAUGE" ) ) {
+        TVHAUPREMOTEOpen( app_ctx, cb );
+        Remote_type = REMOTE_TYPE_HAUPPAUGE;
+    }
+    else if ( STREQ( type_str, "PIXELVIEW" ) ) {
+        TVPIXELVIEWREMOTEOpen( app_ctx, cb );
+        Remote_type = REMOTE_TYPE_PIXELVIEW;
+    }
+    else {
+        fprintf( stderr, 
+          "TVREMOTEOpen: Only X10, HAUPPAUGE, and PIXELVIEW remotes "
+          "are supported.\n" );
+        exit(1);
+    }
 }
 
 
@@ -719,18 +840,9 @@ void TVREMOTEOpen( XtAppContext       app_ctx,
 
 void TVREMOTEFlush( void )
 {
-    unsigned char  btn;
-
-    /*  Do nothing if we didn't open the remote  */
-    if ( Remote_fd < 0 )
-        return;
-
-    /*  Loop while still data  */
-    while (1) {
-
-        /*  Grab a key (until buffer empty)  */
-        if ( read( Remote_fd, &btn, 1 ) <= 0 )
-            break;
-        RMPRINTF(( "TVREMOTE:  Flushing buffer (key = %d)\n", btn ));
-    }
+  switch ( Remote_type ) {
+    case REMOTE_TYPE_X10       :  TVX10REMOTEFlush();  break;
+    case REMOTE_TYPE_HAUPPAUGE :  TVHAUPREMOTEFlush(); break;
+    case REMOTE_TYPE_PIXELVIEW :  TVPIXELVIEWREMOTEFlush(); break;
+  }
 }
