@@ -34,6 +34,8 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <unistd.h>
+#include <assert.h>
 #include <X11/Xlib.h>
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -47,7 +49,6 @@
 #include "app_rsrc.h"
 
 #include "tvdefines.h"
-#include "eventnames.h"
 #include "tvutil.h"
 #include "tvmenu.h"
 #include "tvscreen.h"
@@ -55,6 +56,9 @@
 #include "batch_mode.h"
 #include "remote.h"
 #include "glob.h"
+#include "remotetrans.h"
+#include "vidsav_dlg.h"
+#include "xutil.h"
 
 /*      ******************** Local defines                ************** */
 
@@ -76,6 +80,7 @@ static Atom         S_wm_delete_window;
 /*      ******************** Forward declarations         ************** */
 
 void _XEditResCheckMessages();
+void _XDefaultError( Display *display, XErrorEvent *err_event );
 
 /*      ******************** Function Definitions         ************** */
 
@@ -136,7 +141,6 @@ static void TVWorkProcTimeoutCB(
          XtPointer          cl_data,
          XtIntervalId      *timer )
 {
-    TV_DISPLAY   *d = &G_glob.display;
     TV_BOOL       restart_video;
 
     /*  Exit if we were asked to  */
@@ -281,7 +285,7 @@ static void TVStationListStrToList(
             TVUTILOutOfMemory();
 
         for ( i = 0; i < TV_MAX_CHANNELS; i++ ) {
-            sprintf( (*station)[i].id, "%d", i+TV_CHAN_MIN );
+            sprintf( (*station)[i].id, "%ld", i+TV_CHAN_MIN );
             (*station)[i].set_via_channel = TRUE;
             (*station)[i].channel         = i+TV_CHAN_MIN;
         }
@@ -298,7 +302,8 @@ static void TVStationListStrToList(
         TV_BOOL     chan_range;
         TV_INT32    alloc_size = 0,
                     num_alloc,
-                    chan1, chan2;
+                    chan1, chan2,
+                    tmp_int;
 
         if ( !s )
             TVUTILOutOfMemory();
@@ -323,13 +328,16 @@ static void TVStationListStrToList(
             if (( sscanf( tok, "%[^()](f%f)", new.id, &new.freq ) == 2 ) ||
                 ( sscanf( tok, "%[^()](F%f)", new.id, &new.freq ) == 2 ))
                 new.set_via_channel = FALSE;
-            else if ( sscanf( tok, "%[^()](%d)", new.id, &new.channel ) == 2 )
+            else if ( sscanf( tok, "%[^()](%ld)", new.id, &tmp_int ) == 2 ) {
                 new.set_via_channel = TRUE;
-            else if ( sscanf( tok, "%d-%d", &chan1, &chan2 ) == 2 )
+                new.channel         = tmp_int;
+            }
+            else if ( sscanf( tok, "%ld-%ld", &chan1, &chan2 ) == 2 )
                 chan_range = TRUE;
-            else if ( sscanf( tok, "%d", &new.channel ) == 1 ) {
-                sprintf( new.id, "%d", new.channel );
+            else if ( sscanf( tok, "%ld", &tmp_int ) == 1 ) {
                 new.set_via_channel = TRUE;
+                new.channel         = tmp_int;
+                sprintf( new.id, "%d", new.channel );
             }
             else {
                 fprintf( stderr, "Invalid station def: '%s' ...skipped\n", 
@@ -337,8 +345,6 @@ static void TVStationListStrToList(
                 continue;
             }
 
-            TVUTILstrupr( new.id );
-
             /*  Further validation  */
             if (( !chan_range && new.set_via_channel &&
                   ( new.channel < 0 ) ) ||
@@ -365,7 +371,7 @@ static void TVStationListStrToList(
                 memcpy( &(*station)[i++], &new, sizeof(new) );
             else 
                 for ( ; chan1 <= chan2; chan1++ ) {
-                    sprintf( new.id, "%d", chan1 );
+                    sprintf( new.id, "%ld", chan1 );
                     new.set_via_channel = TRUE;
                     new.channel         = chan1;
                     new.freq            = 0.0;
@@ -394,18 +400,6 @@ static void TVStationListStrToList(
 static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
                                          TV_PREFS   *p )
 {
-    static const struct {
-        TV_FREQ_SET  set;
-        char        *str;
-    } S_freq_set_list[] = {
-        { TV_FREQ_SET_NABCST  , "nabcst"   },
-        { TV_FREQ_SET_CABLEIRC, "cableirc" },
-        { TV_FREQ_SET_CABLEHRC, "cablehrc" },
-        { TV_FREQ_SET_WEUROPE , "weurope"  },
-        { TV_FREQ_SET_JPNBCST , "jpnbcst"  },
-        { TV_FREQ_SET_JPNCABLE, "jpncable" },
-        { TV_FREQ_SET_XUSSR   , "xussr"    },
-    };
     static const struct {
         TV_INPUT_FORMAT  mode;
         const char      *str;
@@ -423,8 +417,6 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
     };
 
     TV_DISK                *dsk = &G_glob.disk;
-    TV_DISPLAY             *d = &G_glob.display;
-    TV_XSCREEN             *x = &G_glob.x;
     TV_DRIVER_STATE         s;
     TV_INPUT_FORMAT         input_format;
     TV_INPUT_DEVICE         video_input_dev;
@@ -457,14 +449,9 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
             App_res.display_fps = c->fps_max;
         App_res.display_fps = MAX( 1, MIN( c->fps_max, App_res.display_fps ) );
 
-        /*  Channel  */
-        if (( App_res.def_chan >= TV_CHAN_MIN ) &&
-            ( App_res.def_chan <= TV_CHAN_MAX ))
-            TVCAPTURESetTunerChannel( c, App_res.def_chan );
-
         /*  Cable/antenna tuner frequency modes  */
-        p->ant_freq_set   = TV_FREQ_SET_NABCST;
-        p->cable_freq_set = TV_FREQ_SET_CABLEIRC;
+        p->ant_freq_set   = 1;
+        p->cable_freq_set = 1;
 
         for ( i = 0; i < 2; i++ ) {
             TV_FREQ_SET *set = (i == 0) ? &p->ant_freq_set 
@@ -478,11 +465,18 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
                 strncat( str, App_res.cable_freq_set, sizeof(str)-1 );
             for ( p = str; *p != '\0'; p++ ) 
                 *p = tolower( *p );
-            for ( j = 0; j < XtNumber( S_freq_set_list ); j++ ) 
-                if ( strstr( str, S_freq_set_list[j].str ) != NULL ) {
-                    *set = S_freq_set_list[j].set;
-                    break;
-                }
+
+            for ( j = 1; ; j++ ) {
+                 if ( (p = TVCAPTUREGetTunerFreqSetName(c,j)) == NULL  ) {
+                   fprintf( stderr,
+                       "Unknown or unsupported channelset: \"%s\"\n", str );
+                   exit(1);
+                 } 
+                 if ( strstr( str, p ) != NULL ) {
+                     *set = j;
+                     break;
+                 }
+            }
         }
 
         /*  Tuner mode: antenna/cable  */
@@ -532,6 +526,9 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
         else if (( strstr( App_res.def_audio_input, "internal" ) != NULL ) ||
                  ( strstr( App_res.def_audio_input, "INTERNAL" ) != NULL ))
             audio_input_dev = TV_AUDIO_INPUT_INTERN;
+        else if (( strstr( App_res.def_audio_input, "auto" ) != NULL ) ||
+                 ( strstr( App_res.def_audio_input, "AUTO" ) != NULL ))
+            audio_input_dev = TV_AUDIO_INPUT_AUTO;
 
         if ( audio_input_dev != -1 )
             TVCAPTURESetAudioInputDevice( c, audio_input_dev );
@@ -559,9 +556,25 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
     }
 
     /*  Last minute tweaks  */
+
     if (( s.tuner_chan < TV_CHAN_MIN ) || ( s.tuner_chan > TV_CHAN_MAX ))
        TVCAPTURESetTunerChannel( c, 3 );
 
+    /*  Default channel  */
+    if ( App_res.def_chan[0] && !STREQ( App_res.def_chan, "0" ) ) {
+      XEvent       xev;
+
+      /*  Set up a dummy xevent  */
+      memset( &xev, '\0', sizeof(xev) );
+      xev.xany.type       = ClientMessage;
+      xev.xclient.display = TVDISPLAY;
+      xev.xclient.window  = XtWindow( G_glob.display.video_wgt );
+
+      /*  Count args  */
+      XtCallActionProc( G_glob.display.video_wgt, "TVSetStation", 
+                        &xev, &App_res.def_chan, 1 );
+    }
+
     /*  Update menu/toolbar with currently selected options  */
     TVMENUSetSelectedInputDevice( s.input_dev );
     TVMENUSetSelectedInputFormat( s.input_fmt );
@@ -572,7 +585,143 @@ static void TVSetInitialCaptureDefaults( TV_CAPTURE *c,
 
     /*  Allow user to force no direct video  */
     if ( App_res.disable_direct_v )
-        fprintf( stderr, "Direct video disable on request\n" );
+        fprintf( stderr, "Direct video disabled on request\n" );
+}
+
+/**@BEGINFUNC**************************************************************
+
+    Prototype  : static void TVCreateTopLevelShell(
+                      XtAppContext  *app_context,
+                      Widget        *top_level,
+                      int            argc,
+                      char          *argv[] )
+
+    Purpose    : Determine which visual we want the app to run in,
+                 and invoke the appropriate X magic to make that happen.
+
+    Programmer : 16-Oct-99  Randall Hopper
+
+    Parameters : app_context - O: Xt application context
+                 top_level   - O: Xt top level shell widget
+                 argc        - I: main() argc
+                 argv        - I: main() argv
+
+    Returns    : None.
+
+    Globals    : None.
+
+ **@ENDFUNC*****************************************************************/
+
+static void TVCreateTopLevelShell( 
+              XtAppContext  *app_context,
+              Widget        *top_level,
+              int            argc,
+              char          *argv[] )
+{
+    Display       *display;
+    int           screen;
+    XVisualInfo  *fb_visual;
+    char        **xargv;  /* saved argument vector */
+    int           xargc;    /* saved argument count */
+
+    /*  Save command line args  */
+    xargc = argc;
+    xargv = (char **) XtMalloc (argc * sizeof (char *));
+    if ( !xargv )
+        TVUTILOutOfMemory();
+    memcpy( xargv, argv, argc * sizeof( argv[0] ) );
+
+    /*  Create a dummy top level to pull resources and get displays,  */
+    /*    screens, etc.                                               */
+    *top_level = XtVaAppInitialize(
+                   app_context, "Fxtv", 
+                   Cmd_line_options, XtNumber(Cmd_line_options), 
+                   &argc, argv,
+                   fallback_resources,
+                   NULL );
+
+    display = XtDisplay( *top_level );
+    screen  = XScreenNumberOfScreen( XtScreen( *top_level ) );
+
+    /*  Ask the screen module which visual matches up with the frame  */
+    /*    buffer visual.  That's the one we want (direct video!)      */
+    XUTILDetermineFrameBufferVisual( display, screen, &fb_visual );
+
+    /*  Now, create a new application shell in that visual  */
+    if ( fb_visual->visual != 
+         DefaultVisualOfScreen( XtScreen( *top_level ) ) ) {
+        static Pixmap visual_pixmap = None;
+        Window        root_win   = RootWindowOfScreen( XtScreen(*top_level) );
+        XVisualInfo   vinfo;
+        XVisualInfo  *vinfo_list;
+        int           vinfo_len;
+        Colormap      colormap;
+        int           depth;
+
+        fprintf( stderr, 
+                 "\nWARNING:  Non-default X visuals not supported yet.\n\n");
+        fflush( stderr );
+
+        vinfo.visualid = XVisualIDFromVisual( fb_visual->visual );
+        vinfo_list     = XGetVisualInfo( display, VisualIDMask, 
+                                         &vinfo, &vinfo_len );
+        assert( vinfo_list && vinfo_len > 0 );
+        depth = vinfo_list[0].depth;
+        XFree( vinfo_list );
+
+        colormap = XCreateColormap( display, root_win, fb_visual->visual, 
+                                    AllocNone );
+
+        visual_pixmap = XCreatePixmap( display, root_win, 1, 1, depth );
+    
+        /*  Stuff the visual into the Xt database so we don't have to      */
+        /*    set this stupid thing on every shell widget we create.       */
+        /*    (all because the X folk made visual a Shell-only resource).  */
+        {
+            XrmDatabase db = XtDatabase( display );
+            XrmValue    v;
+
+            v.size = sizeof( fb_visual->visual );
+            v.addr = (XtPointer) &fb_visual->visual;
+            XrmPutResource( &db, "*visual", XtCVisual, &v );
+
+            /*  FIXME:  Probably don't need these */
+#ifdef OLDSTUFF
+            v.size = sizeof( colormap );
+            v.addr = (XtPointer) &colormap;
+            XrmPutResource( &db, "*Colormap" , XtCColormap, &v );
+
+            v.size = sizeof( visual_pixmap );
+            v.addr = (XtPointer) &visual_pixmap;
+            XrmPutResource( &db, "*borderPixmap" , XtCPixmap, &v );
+
+            v.size = sizeof( depth );
+            v.addr = (XtPointer) &depth;
+            XrmPutResource( &db, "*depth" , XtRInt /*FIXME:XtR? */, &v );
+#endif
+        }
+        
+        XtDestroyWidget( *top_level );
+
+        *top_level = XtVaAppCreateShell( (char *)NULL, "Fxtv",
+                                  applicationShellWidgetClass, display,
+                                  XtNargv        , xargv,
+                                  XtNargc        , xargc,
+                                  XtNvisual      , fb_visual->visual,
+                                  XtNcolormap    , colormap,
+                                  XtNdepth       , depth,
+                                  XtNborderPixmap, visual_pixmap,
+                                  NULL );
+    }
+    else {
+        XtDestroyWidget( *top_level );
+
+        *top_level = XtVaAppCreateShell( (char *)NULL, "Fxtv",
+                                  applicationShellWidgetClass, display,
+                                  XtNargv     , xargv,
+                                  XtNargc     , xargc,
+                                  NULL );
+    }
 }
 
 
@@ -639,7 +788,7 @@ static void TVCreateWidgets(
 }
 
 
-void main( int argc, char *argv[] )
+int main( int argc, char *argv[] )
 {
     static XtActionsRec S_tv_actions[] = {
         { "WMDeleteWindow", (XtActionProc) TVWMDeleteWindow }
@@ -647,7 +796,6 @@ void main( int argc, char *argv[] )
 
     XtAppContext  app_context;
     Widget        top_level;
-    int           i;
     TV_DISPLAY   *d = &G_glob.display;
     TV_PREFS     *p = &G_glob.prefs;
     TV_CAPTURE   *c = &G_glob.capture;
@@ -656,16 +804,9 @@ void main( int argc, char *argv[] )
     if ( DoBatchMode(argc,argv) ) 
         exit(0);
 
-    XUTILAugmentXEnv( argv[0] );
-
     XtSetLanguageProc(NULL, (XtLanguageProc)NULL, NULL);
-
-    top_level = XtVaAppInitialize(
-        &app_context, "Fxtv", 
-        Cmd_line_options, XtNumber(Cmd_line_options), 
-        &argc, argv,
-        fallback_resources,
-        NULL );
+    
+    TVCreateTopLevelShell( &app_context, &top_level, argc, argv );
 
     XSetErrorHandler( (int (*)(Display *dpy, XErrorEvent *err_event))
                       TVXErrorHdlr );
@@ -702,8 +843,8 @@ void main( int argc, char *argv[] )
     /*  Attach remote, if configured  */
     if ( App_res.remote_type[0] && !STREQ( App_res.remote_type, "None" ) && 
                                    !STREQ( App_res.remote_type, "none" ) ) {
-        TVREMOTEOpen( app_context, App_res.remote_type, TVRemoteCallback );
         TVREMOTETRANSParse( XtDisplay( top_level ) );
+        TVREMOTEOpen( app_context, App_res.remote_type, TVRemoteCallback );
     }
     
     XtVaSetValues( top_level, XtNallowShellResize, True,
