@@ -35,8 +35,15 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <sys/mman.h>
-#include <machine/ioctl_bt848.h>
+#ifdef __NetBSD__
+# include <dev/pci/bt848var.h>
+# include <dev/pci/meteorvar.h>
+#else
+# include <machine/ioctl_bt848.h>
+#endif
 #include <signal.h>
+#include <sys/ioctl.h>
+#include <unistd.h>
 #include "tvdefines.h"
 #include "tvtypes.h"
 #include "tvcapture.h"
@@ -50,10 +57,10 @@
 #  define BT848SFMT METEORSFMT
 #endif
 
-#if defined(__FreeBSD__)
+#ifndef linux
 #  define DEV_BT848   "/dev/bktr%d"
 #  define DEV_TUNER   "/dev/tuner%d"
-#elif defined(linux)
+#else
 #  warning FIXME: Does/how does Linux name multiple devices of the same type
 #  warning        Is there a consistent policy as in FreeBSD?
 #  define DEV_BT848   "/dev/bt848"
@@ -229,10 +236,10 @@ TV_BOOL TVCAPTUREGetPendingFrame( TV_IMAGE **img )
         static TV_IMAGE      image;
 
         if (( S_frame_done_count == 0 ) || ( c->frame_done_cb == NULL ))
-            return;
+            return FALSE;
 
         if ( S_frame_done_count-- > 0 )
-            DRVPRINTF(( "%d frames behind\n", S_frame_done_count ));
+            DRVPRINTF(( "%ld frames behind\n", S_frame_done_count ));
 
         image.buf = c->drv_buf;
         memcpy( &image.geom, &c->geom, sizeof( image.geom ) );
@@ -243,7 +250,7 @@ TV_BOOL TVCAPTUREGetPendingFrame( TV_IMAGE **img )
     }
     else {
         *img = NULL;
-        return False;
+        return FALSE;
     }
 }
 
@@ -453,6 +460,8 @@ void TVCAPTURESetInputFormat( TV_CAPTURE *c, TV_INPUT_FORMAT format )
             c->height_max = PAL_DIM_Y;
             c->fps_max    = PAL_FPS;
             break;
+        case TV_INPUT_AUTO     : 
+            abort();
     }
     /*  FIXME: Dead code  */
     c->input_format = format;
@@ -628,19 +637,7 @@ void TVCAPTURESetTunerFreqSet( TV_CAPTURE *c, TV_FREQ_SET set )
 {
     TV_INT32 larg;
 
-    switch ( set ) {
-        case TV_FREQ_SET_NABCST   : larg = CHNLSET_NABCST  ;  break;
-        case TV_FREQ_SET_CABLEIRC : larg = CHNLSET_CABLEIRC;  break;
-        case TV_FREQ_SET_CABLEHRC : larg = CHNLSET_CABLEHRC;  break;
-        case TV_FREQ_SET_WEUROPE  : larg = CHNLSET_WEUROPE ;  break;
-        case TV_FREQ_SET_JPNBCST  : larg = CHNLSET_JPNBCST ;  break;
-        case TV_FREQ_SET_JPNCABLE : larg = CHNLSET_JPNCABLE;  break;
-        case TV_FREQ_SET_XUSSR    : larg = CHNLSET_XUSSR   ;  break;
-        default :
-             fprintf( stderr,
-                      "TVCAPTURESetTunerFreqSet(): Bad freq set %d\n", set ); 
-             return;
-    }
+    larg = set;
     
     if ( ioctl( c->tfd, TVTUNER_SETTYPE, &larg ) < 0 ) {
         DO_IOCTL_SERR( "TVTUNER_SETTYPE", larg );
@@ -659,6 +656,53 @@ void TVCAPTURESetTunerFreqSet( TV_CAPTURE *c, TV_FREQ_SET set )
     }
 }
 
+char *TVCAPTUREGetTunerFreqSetName( TV_CAPTURE *c, TV_FREQ_SET set )
+{
+#ifdef TVTUNER_GETCHNLSET
+    static struct bktr_chnlset cset;
+    int ret;
+
+    cset.index = set;
+    if ( ( ret = ioctl( c->tfd, TVTUNER_GETCHNLSET, &cset ) ) == 0 ) {
+        return (char *)&cset.name;
+    } else {
+        if (ret == EINVAL) {
+           return NULL;
+        } 
+        else {
+#endif
+            switch (set) {
+                case CHNLSET_NABCST:
+                    return "nabcst";
+                case CHNLSET_CABLEIRC:
+                    return "cableirc";
+                case CHNLSET_CABLEHRC:
+                    return "cablehrc";
+                case CHNLSET_WEUROPE:
+                    return "weurope";
+                case CHNLSET_JPNBCST:
+                    return "jpnbcst";
+                case CHNLSET_JPNCABLE:
+                    return "jpncable";
+/* FIXME:  Remove these #ifdefs when these channel sets are standard  */
+#ifdef CHNLSET_XUSSR
+                case CHNLSET_XUSSR:
+                    return "xussr";
+#endif
+#ifdef CHNLSET_AUSTRALIA
+                case CHNLSET_AUSTRALIA:
+                    return "australia";
+#endif
+                default:
+                    return NULL;
+            }
+#ifdef TVTUNER_GETCHNLSET
+        }
+    }
+#endif
+
+}
+
 void TVCAPTURESetAfc( TV_CAPTURE *c, TV_BOOL afc )
 {
     if ( ioctl( c->tfd, TVTUNER_SETAFC, &afc ) < 0 ) {
@@ -762,7 +806,7 @@ TV_BOOL TVCAPTUREQueryDriverState( TV_CAPTURE *c, TV_DRIVER_STATE *s )
         case METEOR_INPUT_DEV_SVIDEO : s->input_dev = TV_DEVICE_SVIDEO ; break;
         case METEOR_INPUT_DEV2       : s->input_dev = TV_DEVICE_CSVIDEO; break;
         default :
-             fprintf( stderr, "TVCAPTUREQueryDriverState(): Bad INPUT %d\n",
+             fprintf( stderr, "TVCAPTUREQueryDriverState(): Bad INPUT %ld\n",
                       larg );
              return False;
     }
@@ -782,7 +826,7 @@ TV_BOOL TVCAPTUREQueryDriverState( TV_CAPTURE *c, TV_DRIVER_STATE *s )
         case BT848_IFORM_F_SECAM   : s->input_fmt = TV_INPUT_SECAM   ;  break;
         case BT848_IFORM_F_RSVD    : s->input_fmt = TV_INPUT_PALNCOMB;  break;
         default :
-             fprintf( stderr, "TVCAPTUREQueryDriverState(): Bad FMT %d\n",
+             fprintf( stderr, "TVCAPTUREQueryDriverState(): Bad FMT %ld\n",
                       larg );
              return False;
     }
@@ -877,27 +921,7 @@ TV_BOOL TVCAPTUREQueryDriverState( TV_CAPTURE *c, TV_DRIVER_STATE *s )
         DO_IOCTL_GERR( "TVTUNER_GETTYPE" );
         return False;
     }
-    switch ( larg ) {
-        case CHNLSET_NABCST   : s->tuner_freq_set = TV_FREQ_SET_NABCST  ;  
-                                break;
-        case CHNLSET_CABLEIRC : s->tuner_freq_set = TV_FREQ_SET_CABLEIRC;  
-                                break;
-        case CHNLSET_CABLEHRC : s->tuner_freq_set = TV_FREQ_SET_CABLEHRC;   
-                                break;
-        case CHNLSET_WEUROPE  : s->tuner_freq_set = TV_FREQ_SET_WEUROPE ;  
-                                break;
-        case CHNLSET_JPNBCST  : s->tuner_freq_set = TV_FREQ_SET_JPNBCST ;  
-                                break;
-        case CHNLSET_JPNCABLE : s->tuner_freq_set = TV_FREQ_SET_JPNCABLE;  
-                                break;
-        case CHNLSET_XUSSR    : s->tuner_freq_set = TV_FREQ_SET_XUSSR;  
-                                break;
-        default :
-             fprintf( stderr,
-                      "TVCAPTUREQueryDriverState(): Bad CHNLSET %d\n", 
-                      larg );
-             return False;
-    }
+    s->tuner_freq_set = larg;
 
     /*  FIXME:  This is a hack because we can't query this info  */
     /*    from the driver.                                       */
@@ -1066,6 +1090,8 @@ void TVCAPTUREQueryPixelFormats( TV_CAPTURE     *c,
                     pg->frame_packing = TV_FRAME_PLANAR;
                     strcpy( pg->comp_order, "YUV" );
                     break;
+
+                default:  break; /*  Won't happen  */
             }
         }
         else {
@@ -1160,7 +1186,6 @@ static TV_BOOL TVCAPTUREMaskIsaByte ( TV_UINT32 mask )
 void TVCAPTUREGetPixFmtByPixGeom( TV_CAPTURE *c, TV_PIXEL_GEOM *geom,
                                   TV_INT32 *index )
 {
-    static    TV_BOOL S_recursive_lock = FALSE;
     TV_UINT32 i;
 
     for ( i = 0; i < c->pix_geom_list_len; i++ )
@@ -1199,7 +1224,6 @@ void TVCAPTUREGetPixFmtByPixGeom( TV_CAPTURE *c, TV_PIXEL_GEOM *geom,
 void TVCAPTUREPrintPixelFormats( TV_CAPTURE *c )
 {
     TV_INT32       i,
-                   j,
                    bpp,
                    swap;
     TV_UINT32      mask;
@@ -1256,7 +1280,7 @@ void TVCAPTUREPrintPixelFormats( TV_CAPTURE *c )
         }
 
         SUPRINTF(( 
-            "    %2d  %2d   %.8x, %.8x, %.8x  %s\n",
+            "    %2ld  %2ld   %.8lx, %.8lx, %.8lx  %s\n",
             bpp, pg->Bpp, pg->mask[0], pg->mask[1], pg->mask[2], 
             swap_chars ));
     }
@@ -1267,18 +1291,14 @@ void TVCAPTUREPrintPixelFormats( TV_CAPTURE *c )
        "   -------  -----  -----  ------  ---------  ----  ----  ------\n" ));
 
     for ( i = 0; i < c->pix_geom_list_len; i++ ) {
-        char          swap_chars[5];
-        TV_INT32      j;
-        TV_PIXEL_GEOM scratch;
-        TV_BOOL       printit = TRUE;
-
         pg = &c->pix_geom_list[ i ];
 
         if ( pg->type != TV_PIXELTYPE_YUV )
             continue;
         
         SUPRINTF(( 
-          "    %d,%d,%d   %d,%d,%d  %d,%d,%d  %-7s %-10s  %-5s %-6s %s\n",
+          "    %ld,%ld,%ld   %ld,%ld,%ld  %ld,%ld,%ld  %-7s %-10s  "
+          "%-5s %-6s %s\n",
           pg->samp_size [0], pg->samp_size [1], pg->samp_size [2],
           pg->samp_int_h[0], pg->samp_int_h[1], pg->samp_int_h[2],
           pg->samp_int_v[0], pg->samp_int_v[1], pg->samp_int_v[2],
@@ -1317,7 +1337,6 @@ static void TVCAPTUREDumpCaptureCardInfo( TV_CAPTURE *c )
     u_char         *p;
     int             x;
     int             cnt;
-    TV_INT32        eeprom_size;
     FILE           *fp;
     char            linebuf[128];
 
@@ -1364,7 +1383,7 @@ static void TVCAPTUREDumpCaptureCardInfo( TV_CAPTURE *c )
         printf( "\nTUNER SIGNATURE (0x%02x - 0x%02x):\n",
                 eeprom.offset,
                 (2 * ((eeprom.offset - 1) + eeprom.count)) - 1 );
-        for ( p = &eeprom.bytes[ 0 ], x = 0; x < 128; ++x ) {
+        for ( p = &eeprom.bytes[ 0 ], x = 0; x < 16; ++x ) {
             if ( (x % 16) == 0 )
                 printf( "%s   ", ((x > 0) ? "\n" : "") );
             printf( " %02x", p[ x ] );
@@ -1409,6 +1428,13 @@ static void TVCAPTUREDumpCaptureCardInfo( TV_CAPTURE *c )
         printf( "\n" );
     }
 
+    /*  Dump supported Frequency Sets  */
+    printf( "\nSUPPORTED FREQUENCY SETS:\n");
+
+    cnt=1;
+    while ( (p = TVCAPTUREGetTunerFreqSetName( c, cnt )) != NULL ) 
+        printf( "    %2d %s\n", cnt++, p );
+
     /*  It'd also be helpful to be able to print the bktr driver version  */
 }
 
@@ -1530,7 +1556,8 @@ void TVCAPTUREInit( TV_CAPTURE *c )
         default                :
         case TV_INPUT_AUTO     :
             fprintf( stderr, 
-             "TVCAPTUREInit: Unsupported input format %d\n", c->input_format );
+             "TVCAPTUREInit: Unsupported input format %ld\n", 
+             c->input_format );
             exit(1);
     }
     c->fps           = c->fps_max;
@@ -1676,8 +1703,7 @@ TV_BOOL TVCAPTUREConfigure( TV_CAPTURE       *c,
     TV_DISPLAY       *d = &G_glob.display;
     TV_GEOM           g;
     TV_UINT32         addr;
-    TV_INT32          Bpp,
-                      idx;
+    TV_INT32          Bpp;
 
     if ( c->contin_on == TRUE ) {
         strcpy( S_err_msg, "Continuous is running" );
@@ -1717,7 +1743,7 @@ TV_BOOL TVCAPTUREConfigure( TV_CAPTURE       *c,
     /*  Verify res limits and precision (all modes)  */
     if (( g.w != g.w / c->width_res  * c->width_res  ) ||
         ( g.h != g.h / c->height_res * c->height_res )) {
-        sprintf( S_err_msg, "Capture geometry must be a multiple of %dx%d",
+        sprintf( S_err_msg, "Capture geometry must be a multiple of %ldx%ld",
                  c->width_res, c->height_res );
         goto RETURN;
     }
@@ -1740,7 +1766,7 @@ TV_BOOL TVCAPTUREConfigure( TV_CAPTURE       *c,
         if ( x->visual[ x->active_visual ].visualid != 
                x->fb_visual->visualid ) {
             strcpy( S_err_msg, 
-                    "Active X Visual is not the default visual" );
+                    "Active X Visual is not the visual of the frame buffer" );
             goto RETURN;
         }
         if ( d->win == None ) {
@@ -1804,7 +1830,6 @@ void TVCAPTUREStart( TV_CAPTURE *c )
 {
     static TV_BOOL S_done_a_single = False;
 
-    TV_DISPLAY          *d = &G_glob.display;
     TV_XSCREEN          *x = &G_glob.x;
     TV_INT32             larg;
     struct meteor_video  video;
@@ -1909,10 +1934,10 @@ void TVCAPTUREStart( TV_CAPTURE *c )
         return;
     }
     /*printf( "SACTPIXFMT = { idx %d, Bpp %d, masks { %x,%x,%x }, "
-			   "swapb/s %d,%d }\n",
+                           "swapb/s %d,%d }\n",
             pix_geom.index, pix_geom.Bpp, pix_geom.mask[0],
-	    pix_geom.mask[1], pix_geom.mask[2], pix_geom.swap_bytes,
-	    pix_geom.swap_shorts );*/
+            pix_geom.mask[1], pix_geom.mask[2], pix_geom.swap_bytes,
+            pix_geom.swap_shorts );*/
     if ( ioctl( c->fd, METEORSACTPIXFMT, &pix_geom.index ) < 0 ) {
         DO_IOCTL_SERR( "METEORSACTPIXFMT", &geom );
         return;
@@ -2042,4 +2067,3 @@ void TVCAPTUREStop( TV_CAPTURE *c )
 
     TVCAPTUREClearPendingFrames();
 }
-
