@@ -52,7 +52,12 @@
 #include "tvscreen.h"
 #include "xutil.h"
 #include "glob.h"
+#include "actions.h"
 #include "tvmenu.h"
+#include "imgsav_dlg.h"
+#include "appear_dlg.h"
+#include "audsav_dlg.h"
+#include "vidsav_dlg.h"
 
 /*      ******************** Local defines                ************** */
 
@@ -100,7 +105,7 @@ typedef void XT_CB( Widget w, XtPointer client_data, XtPointer cb_data );
 
 static XT_CB QuitCB, FreezeCB, MuteCB, ZoomCB, InputCB, AfcCB, TModeCB, 
              ChanUpDnCB, AppearCB, AspectCB, AboutCB, ImgSavCB, ImgSavAsCB, 
-             AudSavAsCB, VidSavAsCB, FormatCB, AudInpCB;
+             AudSavAsCB, VidSavAsCB, FormatCB, AudInpCB, StationPopupCB;
 
 /*      ******************** Private variables            ************** */
 
@@ -212,19 +217,19 @@ static char Chan_text_transl[] =  "\
 <Key>Linefeed: select-all() beginning-of-line() "CHANTEXT_ACCEPT_ACTION"()\n\
 Ctrl<Key>J:    select-all() beginning-of-line() "CHANTEXT_ACCEPT_ACTION"()\n\
 Ctrl<Key>M:    select-all() beginning-of-line() "CHANTEXT_ACCEPT_ACTION"()\n\
+<Btn3Down>:    XawPositionSimpleMenu(stationpopup) MenuPopup(stationpopup)\n\
 <Key>Delete: delete-previous-character() \n\
 <Key>BackSpace: delete-previous-character() \n\
 <Key>: kill-to-end-of-line() insert-char()\
 ";
-/*
-*/
 
 
 
 static void ChanTextAcceptAction( Widget, XEvent *, String *, Cardinal *);
 
-static XtActionsRec Tool_actions[1] = 
-           { CHANTEXT_ACCEPT_ACTION, ChanTextAcceptAction };
+static XtActionsRec Tool_actions[1] = {
+           { CHANTEXT_ACCEPT_ACTION, ChanTextAcceptAction }
+};
 
 /*      ******************** Function Definitions         ************** */
 
@@ -288,7 +293,6 @@ static void FreezeCB( Widget w, XtPointer cl, XtPointer cb )
 static void ZoomCB( Widget w, XtPointer cl, XtPointer cb )
 {
     Boolean  zoom_on;
-    TV_GEOM  g;
     
     XtVaGetValues( w, XtNstate, &zoom_on,
                       NULL );
@@ -527,6 +531,127 @@ static void ChanTextAcceptAction(
     TVActionSetStation( chan_str );
 }
 
+/*  StationPopupCB - Callback invoked when a station in our station menu  */
+/*                   popup is invoked.                                    */
+static void StationPopupCB( Widget w, XtPointer cl, XtPointer cb )
+{ 
+    String new_station;
+
+    XtVaGetValues(w, XtNlabel, &new_station, NULL);
+    TVActionSetStation(new_station);
+}
+
+/*  TVTOOLSUpdateStationPopup - Reset the selected station on the   */
+/*                              station pop-up menu                 */
+static void TVTOOLSUpdateStationPopup()
+{
+    Widget popup_win, new_popup_item = NULL;
+    Cardinal num_children, i;
+    WidgetList children;
+    String actual_station, temp_station;
+#ifdef FIXME
+    Pixmap pix;
+#endif
+    TV_TOOLITEM_DEF *chantext = LookupToolItemByKey( TV_TOOLITEM_CHANTEXT );
+
+    /*  FIXME:  Popup geometry negotiation doesn't seem to work when  */
+    /*    we specify a left bitmap -- stomps on text.  Possibly       */
+    /*    some other geometry manager tweak needed here.              */
+
+    popup_win = XtNameToWidget(chantext->wgt, "stationpopup");
+
+    if(popup_win == NULL)
+        return;
+
+    XtVaGetValues(chantext->wgt, XtNstring, &actual_station, NULL);
+    assert(actual_station);
+
+    XtVaGetValues(popup_win, XtNnumChildren, &num_children,
+                          XtNchildren,    &children,
+                          NULL);
+
+    for( i = 0; i < num_children; i++)
+    {
+        XtVaGetValues(children[i], XtNlabel, &temp_station, NULL);
+        assert(temp_station);
+
+#ifdef FIXME
+        if ( strcmp( actual_station, temp_station ) != 0 )
+            pix = Unselect_pixmap;
+        else {
+            pix = Select_pixmap;
+            new_popup_item = children[i];
+        }
+
+        XtVaSetValues(children[i], XtNleftBitmap, pix, NULL);
+#else
+        if ( strcmp( actual_station, temp_station ) == 0 )
+            new_popup_item = children[i];
+#endif
+    }
+    
+    XtVaSetValues(popup_win, XtNpopupOnEntry, new_popup_item, NULL);
+}
+
+/*  TVTOOLSCreateStationPopup - Pop up a simple menu with all of our  */
+/*                              configured stations.                  */
+void TVTOOLSCreateStationPopup()
+{
+    TV_PREFS   *p = &G_glob.prefs;
+    TV_INT32   i,
+               num_chan;
+    TV_STATION *station;
+    Widget     menu_shell, item;
+    String     actual_chan;
+#ifdef FIXME
+    Pixmap     pix;
+#endif
+    TV_TOOLITEM_DEF *chantext = LookupToolItemByKey( TV_TOOLITEM_CHANTEXT );
+
+    /*  Figure out which tuner input we're dealing with  */
+    if ( p->tuner_mode == TV_TUNER_MODE_ANTENNA )
+    {
+        station  = p->ant_station,
+        num_chan = p->ant_num_stations;
+    }
+    else if ( p->tuner_mode == TV_TUNER_MODE_CABLE )
+    {
+        station  = p->cable_station,
+        num_chan = p->cable_num_stations;
+    }
+    else {
+        fprintf( stderr,
+                 "TVTOOLSCreateStationPopup: Unsupported tuner mode\n" );
+        return;
+    }
+    
+    XtVaGetValues(chantext->wgt, XtNstring, &actual_chan, NULL);
+
+    /*  Create the menu and set item callbacks  */
+    menu_shell = XtVaCreatePopupShell( "stationpopup",
+                                       simpleMenuWidgetClass, chantext->wgt,
+                                       NULL );
+    for ( i = 0; i < num_chan; i++ )
+    {
+        /*  FIXME:  Popup geometry negotiation doesn't seem to work when  */
+        /*    we specify a left bitmap -- stomps on text.  Possibly       */
+        /*    some other geometry manager tweak needed here.              */
+#ifdef FIXME
+        if ( strcmp(actual_chan, station[i].id) != 0 )
+            pix = Unselect_pixmap;
+        else
+            pix = Select_pixmap;
+
+        item = XtVaCreateManagedWidget( station[i].id, *WC_mcmd, menu_shell,
+                                        XtNleftBitmap, pix, NULL );
+#else
+        item = XtVaCreateManagedWidget( station[i].id, *WC_mcmd, menu_shell,
+                                        NULL );
+#endif
+        XtAddCallback( item, XtNcallback, StationPopupCB, NULL );
+    }
+}
+
 /*  AppearCB - Bring up the capture appearance parameters dialog  */
 static void AppearCB( Widget w, XtPointer cl, XtPointer cb )
 {
@@ -553,7 +678,7 @@ static void AboutCB( Widget w, XtPointer cl, XtPointer cb )
     XUTILDialogPause( TVTOPLEVEL, "About", 
                       "FreeBSD X TV\n"
                       "Version " VERS_STR "\n\n"
-                      "Written by Randall Hopper, 1997-8.",
+                      "Written by Randall Hopper, 1997-9.",
                       TV_DIALOG_TYPE_OK );
 }
 
@@ -767,7 +892,7 @@ void TVTOOLSSetToggleState( TV_TOOLITEM_KEY key,
             break;
 
     if ( i >= XtNumber( Toolitem_def ) ) {
-        fprintf( stderr, "TVTOOLSETSetToggleState: Bad key %d\n" );
+        fprintf( stderr, "TVTOOLSETSetToggleState: Bad key %ld\n", i );
         exit(1);
     }
 
@@ -787,7 +912,6 @@ Widget TVTOOLSGetVolumeScrollbar( void )
 
 void TVMENUSetSelectedInputDevice( TV_INPUT_DEVICE dev )
 {
-    TV_CAPTURE      *c = &G_glob.capture;
     TV_MENUITEM_DEF *tuner  = LookupMenuItemByKey( TV_MENUITEM_INPUT_TUNER );
     TV_MENUITEM_DEF *video  = LookupMenuItemByKey( TV_MENUITEM_INPUT_VIDEO );
     TV_MENUITEM_DEF *svideo = LookupMenuItemByKey( TV_MENUITEM_INPUT_SVIDEO);
@@ -821,7 +945,6 @@ void TVMENUSetSelectedInputDevice( TV_INPUT_DEVICE dev )
 
 void TVMENUSetSelectedAudioInputDevice( TV_AUDIO_INPUT_DEVICE dev )
 {
-    TV_CAPTURE      *c = &G_glob.capture;
     TV_MENUITEM_DEF *autoc  = LookupMenuItemByKey( TV_MENUITEM_AUDINP_AUTO   );
     TV_MENUITEM_DEF *intern = LookupMenuItemByKey( TV_MENUITEM_AUDINP_INTERN );
     Pixmap           pix;
@@ -843,9 +966,6 @@ void TVMENUSetSelectedAudioInputDevice( TV_AUDIO_INPUT_DEVICE dev )
 
 void TVMENUSetSelectedTunerMode( TV_TUNER_MODE mode )
 {
-    TV_DISPLAY      *d = &G_glob.display;
-    TV_CAPTURE      *c = &G_glob.capture;
-    TV_PREFS        *p = &G_glob.prefs;
     TV_MENUITEM_DEF *ant   = LookupMenuItemByKey( TV_MENUITEM_TMODE_ANTENNA );
     TV_MENUITEM_DEF *cable = LookupMenuItemByKey( TV_MENUITEM_TMODE_CABLE   );
     Pixmap           pix;
@@ -867,9 +987,6 @@ void TVMENUSetSelectedTunerMode( TV_TUNER_MODE mode )
 
 void TVMENUSetSelectedAfcMode( TV_BOOL afc )
 {
-    TV_DISPLAY      *d = &G_glob.display;
-    TV_CAPTURE      *c = &G_glob.capture;
-    TV_PREFS        *p = &G_glob.prefs;
     TV_MENUITEM_DEF *item = LookupMenuItemByKey( TV_MENUITEM_OPTIONS_AFC );
     Pixmap           pix;
 
@@ -883,7 +1000,6 @@ void TVMENUSetSelectedAfcMode( TV_BOOL afc )
 
 void TVMENUSetSelectedAspectLock( TV_BOOL aspect_lock )
 {
-    TV_DISPLAY      *d = &G_glob.display;
     TV_MENUITEM_DEF *item = LookupMenuItemByKey( TV_MENUITEM_OPTIONS_ASPECT );
     Pixmap           pix;
 
@@ -919,9 +1035,12 @@ void TVMENUResync()
     TVMENUSetSelectedAfcMode         ( p->afc_mode   );
 }
 
-/*  TVTOOLSSetStationText  -  Sets the channel text to the specified string  */
+/*  TVTOOLSSetStationText  -  Sets the channel text to the specified      */
+/*                            Also updates window title/icon, if enabled. */
 void TVTOOLSSetStationText( char str[] )
 {
+    static char     *orig_title = NULL;
+    char            *new_title;
     XawTextBlock     tblk;
     TV_TOOLITEM_DEF *chantext = LookupToolItemByKey( TV_TOOLITEM_CHANTEXT );
     char            *old_str;
@@ -939,11 +1058,35 @@ void TVTOOLSSetStationText( char str[] )
                                   NULL );
     old_len = (old_str == NULL) ? 0 : strlen( old_str );
     XawTextReplace( chantext->wgt, 0, old_len, &tblk );
+
+
+    /*  Set a new window title and/or icon, if enabled  */
+    if ( App_res.station_in_win_title ) {
+        if ( orig_title == NULL ) {
+            /* doing it for the first time */
+            char *c_tmp;
+            XtVaGetValues( TVTOPLEVEL, XtNtitle, &c_tmp, NULL );
+            orig_title = strdup( c_tmp );
+            if ( !orig_title )
+                TVUTILOutOfMemory();
+        }
+        new_title = malloc( strlen(orig_title) + strlen(str) + 11 );
+        if ( !new_title )
+            TVUTILOutOfMemory();
+        sprintf( new_title, "%s  *** %s ***", orig_title, str );
+        XtVaSetValues( TVTOPLEVEL, XtNtitle, new_title, NULL );
+        free ( new_title );
+    }
+
+    if ( App_res.station_in_win_icon )
+        XtVaSetValues( TVTOPLEVEL, XtNiconName, str, NULL );
 }
 
 
 void TVTOOLSResync()
 {
+    static int       Station_menu_created = 0;
+    TV_DISPLAY      *d = &G_glob.display;
     TV_CAPTURE      *c = &G_glob.capture;
     TV_DRIVER_STATE  s;
     TV_TOOLITEM_DEF *chantext = LookupToolItemByKey( TV_TOOLITEM_CHANTEXT );
@@ -952,6 +1095,7 @@ void TVTOOLSResync()
     char             chan_str[ 80 ];
     Boolean          sensitive;
     TV_STATION      *station;
+    TV_INT32         line_vol_old, line_vol_new;
 
     assert(( chantext != NULL ) && ( chantext->wgt != NULL ) &&
            ( chanup   != NULL ) && ( chanup->wgt   != NULL ) &&
@@ -963,6 +1107,13 @@ void TVTOOLSResync()
         exit(1);
     }
 
+    /*  Query soundcard's current values  */
+    TVAUDIOGetLineVolume( &line_vol_old );
+    TVAUDIOResync( TRUE );
+    TVAUDIOGetLineVolume( &line_vol_new );
+    if ( line_vol_old != line_vol_new )
+      TVANNOTSignalPropChange( &d->annot, TV_ANNOT_TYPE_VOLUME );
+
     /*  Figure out which station we're on (if any)  */
     TVSTATIONLookup( &s, &station );
 
@@ -984,5 +1135,12 @@ void TVTOOLSResync()
     XtSetSensitive( chantext->wgt, sensitive );
     XtSetSensitive( chanup->wgt  , sensitive );
     XtSetSensitive( chandn->wgt  , sensitive );
+
+    /*  Create the channel popup we'll use later  */
+    if ( !Station_menu_created ) {
+        TVTOOLSCreateStationPopup();
+        Station_menu_created = 1;
+    }
+    TVTOOLSUpdateStationPopup();
 }
 
