@@ -39,7 +39,17 @@
 #  include <sys/sysctl.h>
 #elif defined(linux)
 #  include <linux/sysctl.h>
+#elif defined(__bsdi__)
+#  include <sys/types.h>
+#  include <sys/param.h>
+#  include <sys/sysctl.h>
+#elif defined(__NetBSD__)
+#  include <sys/param.h>
+#  include <sys/sysctl.h>
+#  include <sys/wait.h>
 #endif
+#include <sys/types.h>
+#include <sys/wait.h>
 #include <unistd.h>
 #include "tvdefines.h"
 #include "tvutil.h"
@@ -105,6 +115,10 @@ void CleanupChildFileDesc()
     int    mib[2] = { CTL_KERN, KERN_MAXFILESPERPROC };
 #elif defined(linux)
     int    mib[2] = { CTL_KERN, FOPEN_MAX };
+#elif defined(__bsdi__)
+    int    mib[2] = { CTL_KERN, KERN_MAXFILES };
+#elif defined(__NetBSD__)
+    int    mib[2] = { CTL_KERN, OPEN_MAX };
 #endif
     int    i;
     size_t len;
@@ -159,10 +173,8 @@ void TVUTILCmdStrToArgList(
          char  **argbuf )
 {
     char      *s  = shell_cmd,
-              *s1,
-              *s2,
               *p,
-               quote_char,
+               quote_char = -1,
                arg       [ MAXPATHLEN ];
     TV_INT32   cmd_cnt      = 0,
                cmd_alloc    = 0,
@@ -310,7 +322,7 @@ void TVUTILPipeSetup( char            *shell_cmd,
     if ( debug ) {
         printf( "\nCMD: " );
         if ( shell_cmd )
-            printf( "%s\n" );
+            printf( "%s\n", shell_cmd );
         else {
             int i;
             for ( i = 0; shell_cmd2[i] != NULL; i++ )
@@ -332,8 +344,8 @@ void TVUTILPipeSetup( char            *shell_cmd,
     end[0].fd_saved = end[1].fd_saved = end[2].fd_saved = -1;
 
     /*  Create any needed pipes, first; then fork  */
-    if (( end[0].fd >= 0 ) && end[0].is_pipe && ( pipe( p_fd[0] ) < 0 ) ||
-        ( end[1].fd >= 0 ) && end[1].is_pipe && ( pipe( p_fd[1] ) < 0 ))
+    if ((( end[0].fd >= 0 ) && end[0].is_pipe && ( pipe( p_fd[0] ) < 0 )) ||
+        (( end[1].fd >= 0 ) && end[1].is_pipe && ( pipe( p_fd[1] ) < 0 )))
         { perror( "PipeSetup: pipe failed" ); exit(1); }
 
     if ( ( pid = fork()) < 0 )
