@@ -69,16 +69,8 @@
 
 /*      ******************** Local defines                ************** */
 
-#define FRAME_USEC(fps)     (1000000L /(fps))
-#define PICNAME_FMT         "%s%.5d.%s"
 #define AV_RAWNAME_FMT      "%s.AVraw"
-#define AUDIO_RAW1NAME_FMT  "%s.AUDraw"
-#define AUDIO_RAW2NAME_FMT  "%s.raw"
-#define AUDIO_FNAME_FMT     "%s.%s"
-#define VIDEO_FNAME_FMT     "%s.mpg"
-#define PARAM_FNAME_FMT     "%s.param"
-#define SYSTEM_FNAME_FMT    "%s.mps"
-#define SCRIPT_FNAME_FMT    "%s.sh"
+#define SCRIPT_FNAME_FMT    "%s%s.sh"
 
 #define OPTIMIZE_NUM_FRAMES 200
 
@@ -189,8 +181,7 @@ static TV_BOOL Recording          = FALSE,
                First_image        = TRUE;
 static TV_RAW_VIDEO_FILE *Out_rf  = NULL;
 static TV_SOUND           Snd;
-static int     Dsp_fd           = -1,
-               Wakeup_fd        = -1;
+static int     Dsp_fd           = -1;
 
 /*  FIXME:  Copied from audsav_dlg.c  - This needs abstracted better  */
 static TV_FFMT_ITEM_DEF    Ffmt_item_def[] = {
@@ -278,8 +269,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Icap_fmt_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported filefmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported filefmt %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_icapfmt = choice;
@@ -294,8 +286,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Ifile_fmt_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported filefmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported filefmt %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_ifilefmt = choice;
@@ -310,8 +303,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Ffmt_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported filefmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported filefmt %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_ffmt = choice;
@@ -326,8 +320,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Sfmt_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported sampfmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported sampfmt %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_sfmt = choice;
@@ -342,8 +337,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Chan_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported #chan %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported #chan %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_stereo = choice;
@@ -358,8 +354,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= Rate_item_def_size ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported rate %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported rate %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_rate = choice;
@@ -374,8 +371,9 @@ static void SetMenuSelection( Widget menu_btn, TV_UINT32 choice )
                 break;
             }
         if ( i >= XtNumber( Vtrg_item_def ) ) {
-            fprintf( stderr, "TVVIDSAVDIALOGSetSel: Unsupported filefmt %d\n", 
-                             choice );
+            fprintf( stderr, 
+                     "TVVIDSAVDIALOGSetSel: Unsupported filefmt %lu\n", 
+                     choice );
             exit(1);
         }
         Sel_vtarg = choice;
@@ -450,7 +448,7 @@ static void TextValUpdate( Widget text_wgt, char *str )
 /*  UpdateButtons - Enable/disable btns based on state  */
 static void UpdateButtons()
 {
-    TV_BOOL rec, stop, play, dismiss;
+    TV_BOOL rec, stop, dismiss;
 
     if ( Recording )
         stop = TRUE , rec = dismiss = FALSE;
@@ -490,7 +488,6 @@ static TV_BOOL PrepareForVideo( TV_BOOL optimize_only )
     char        msg[100];
     TV_GEOM     g = { 0,0,0,0 };
     TV_INT32    fps;
-    int         res;
     Boolean     cleanup_temp;
 
     /*  ...Filename base  */
@@ -510,7 +507,7 @@ static TV_BOOL PrepareForVideo( TV_BOOL optimize_only )
                              NULL );
     if ( str == NULL )
         str = "";
-    if (( sscanf( str, "%dx%d", &g.w, &g.h ) != 2 ) ||
+    if (( sscanf( str, "%ldx%ld", &g.w, &g.h ) != 2 ) ||
         !TVCAPTUREValidRegionGeom( c, &g )) {
         XUTILDialogPause( TVTOPLEVEL, "Error", "Invalid size.",
                           TV_DIALOG_TYPE_OK );
@@ -524,7 +521,7 @@ static TV_BOOL PrepareForVideo( TV_BOOL optimize_only )
                                  NULL );
         if ( str == NULL )
             str = "";
-        if (( sscanf( str, "%d", &fps ) != 1 ) ||
+        if (( sscanf( str, "%ld", &fps ) != 1 ) ||
             ( fps < 1 ) || ( fps > c->fps_max )) {
             XUTILDialogPause( TVTOPLEVEL, "Error", "Invalid speed.",
                               TV_DIALOG_TYPE_OK );
@@ -777,14 +774,6 @@ static void UnlinkRawFiles( char      fnames[ 4 ][ MAXPATHLEN ] )
 }
 
 
-/*  FDActivityCB - Dummy input rtn for pipe we use to unblock our "optimize" */
-/*    X event loop.                                                          */
-static void FDActivityCB( XtPointer cl_data, int *fd, XtInputId *id ) 
-{
-    /*  Do nothing  */
-}
-
-
 /**@BEGINFUNC**************************************************************
 
     Prototype  : static TV_BOOL WriteVidConvertShScript(
@@ -812,9 +801,12 @@ static TV_BOOL WriteVidConvertShScript(
     char        *str;
     struct stat  stat;
     TV_INT32     i;
+    TV_BOOL      has_path;
 
     /*  Open output script file  */
-    sprintf( p->script_fname, SCRIPT_FNAME_FMT, p->fname_base );
+    has_path = strchr( "p->fname_base", '/' ) != NULL;
+    sprintf( p->script_fname, SCRIPT_FNAME_FMT, 
+             (has_path ? "./" : ""), p->fname_base );
 
     if ( (fp = fopen( p->script_fname, "wt" )) == NULL ) {
         fprintf( stderr, "Failed to open for write: %s\n", p->script_fname );
@@ -848,7 +840,7 @@ static TV_BOOL WriteVidConvertShScript(
     }
     fprintf( fp, "AUDIO_CAP_FMT_SAMPLE='%s'\n", str );
     fprintf( fp, "AUDIO_CAP_FMT_CHAN='%d'\n", p->snd_fmt.stereo ? 2 : 1 );
-    fprintf( fp, "AUDIO_CAP_FMT_FREQ='%d'\n", p->snd_fmt.samp_rate );
+    fprintf( fp, "AUDIO_CAP_FMT_FREQ='%ld'\n", p->snd_fmt.samp_rate );
 
     switch ( p->snd_fmt.file_fmt ) {
         case TV_AUDIO_FILE_FMT_RAW    : str = "RAW"  ;  break;
@@ -863,8 +855,8 @@ static TV_BOOL WriteVidConvertShScript(
         
     fprintf( fp, "AUDIO_TARGET_FMT='%s'\n\n", str );
 
-    fprintf( fp, "VIDEO_RES_X='%d'\n", p->geom.w );
-    fprintf( fp, "VIDEO_RES_Y='%d'\n", p->geom.h );
+    fprintf( fp, "VIDEO_RES_X='%ld'\n", p->geom.w );
+    fprintf( fp, "VIDEO_RES_Y='%ld'\n", p->geom.h );
    
     switch ( p->img_cap_fmt ) {
         case TV_ICAP_FMT_RGB16 : str = "RGB16";  break;
@@ -875,7 +867,7 @@ static TV_BOOL WriteVidConvertShScript(
     }
 
     fprintf( fp, "VIDEO_CAP_FMT='%s'\n", str );
-    fprintf( fp, "VIDEO_TARGET_FPS='%d'\n", p->fps );
+    fprintf( fp, "VIDEO_TARGET_FPS='%ld'\n", p->fps );
     fprintf( fp, "VIDEO_STREAM='%s'\n\n", ( p->streaming ? "YES" : "NO" ) );
 
     switch ( p->img_sav_fmt ) {
@@ -959,7 +951,6 @@ static void CnvtCmdDoneCB( TV_BOOL aborted, int status, void *cb_data )
     /*  FIXME:  The fxtv_conv.sh script isn't nuking its child processes  */
     /*    and temporary files when it's killed.  It just dies.            */
 
- RETURN:
     DialogSetEnabled( True );
     Recording = FALSE;
     UpdateButtons();
@@ -972,8 +963,6 @@ static void CnvtCmdDoneCB( TV_BOOL aborted, int status, void *cb_data )
 static void RunCnvtCmd( char                 cmd[],
                         char          raw_fnames[ TV_RAW_MAX_FILES ][ MAXPATHLEN ] )
 {
-    TV_DISK            *d   = &G_glob.disk;
-    char                shell_cmd[ MAXPATHLEN + 80 ];
     TVUTIL_PIPE_END     end[3] = {{ -1 }, { -1 }, { -1 }};
     TV_CNVT_CMD_STATE  *state;
     Widget              dialog_shell;
@@ -1213,7 +1202,7 @@ static void RecordCmdCB( Widget w, XtPointer cl, XtPointer cb )
 
         /*  This is a cheesy first-cut  */
         fps = Vid_stats.frames*1000000L/Vid_stats.time_us;
-        sprintf( str, "%d", fps );
+        sprintf( str, "%ld", fps );
         TextValUpdate( FPS_text, str );
     }
 
@@ -1433,7 +1422,7 @@ Widget CreateSingleLineTextField( char wgt_name[], Widget parent )
 
 static void BuildImageCapWgtPanel( Widget parent )
 {
-    Widget    w, gbox, cbox, form, menu_shell;
+    Widget    w, gbox, cbox, menu_shell;
     TV_INT32  i;
 
     gbox = XtVaCreateManagedWidget( "groupBox", boxWidgetClass, parent, 
@@ -1520,7 +1509,7 @@ static void BuildImageCapWgtPanel( Widget parent )
 
 static void BuildImageEncWgtPanel( Widget parent )
 {
-    Widget    w, gbox, cbox, form, menu_shell;
+    Widget    w, gbox, cbox, menu_shell;
     TV_INT32  i;
 
     gbox = XtVaCreateManagedWidget( "groupBox", boxWidgetClass, parent, 
@@ -1710,7 +1699,7 @@ static void BuildAudioCapWgtPanel( Widget parent )
 
 static void BuildAudioEncWgtPanel( Widget parent )
 {
-    Widget    w, gbox, cbox, form, menu_shell;
+    Widget    w, gbox, cbox, menu_shell;
     TV_INT32  i;
 
     gbox = XtVaCreateManagedWidget( "groupBox", boxWidgetClass, parent, 
@@ -1757,7 +1746,7 @@ static void BuildAudioEncWgtPanel( Widget parent )
 
 static void TVVIDSAVDialogBuild( Widget *dialog_wgt )
 {
-    Widget    w, main, main2, sbox, cbox, gbox, form, menu_shell;
+    Widget    w, main1, main2, sbox, cbox, gbox, form, menu_shell;
     TV_INT32  i;
 
     /*  Create the dialog widgets  */
@@ -1765,12 +1754,12 @@ static void TVVIDSAVDialogBuild( Widget *dialog_wgt )
                       transientShellWidgetClass, TVTOPLEVEL,
                       NULL );
 
-    main = XtVaCreateManagedWidget( "mainBox", boxWidgetClass, *dialog_wgt, 
-                                   XtNorientation, XtorientVertical,
-                                   NULL );
-    Main_wgt = main;
+    main1 = XtVaCreateManagedWidget( "mainBox", boxWidgetClass, *dialog_wgt, 
+                                     XtNorientation, XtorientVertical,
+                                     NULL );
+    Main_wgt = main1;
 
-    main2 = XtVaCreateManagedWidget( "groupBox", boxWidgetClass, main, 
+    main2 = XtVaCreateManagedWidget( "groupBox", boxWidgetClass, main1, 
                                    XtNorientation, XtorientVertical,
                                    NULL );
 
@@ -1880,7 +1869,7 @@ static void TVVIDSAVDialogBuild( Widget *dialog_wgt )
                                  XtNjustify, XtJustifyLeft,
                                  NULL );
     /*  Action button form  */
-    form = XtVaCreateManagedWidget( "actionForm", formWidgetClass, main, 
+    form = XtVaCreateManagedWidget( "actionForm", formWidgetClass, main1, 
                                  XtNfromVert, gbox,
                                  NULL );
 
@@ -1937,10 +1926,10 @@ void TVVIDSAVDIALOGResync()
     /*  Set text fields to current settings  */
     TextValUpdate( Fname_text, d->fn_video_base );
 
-    sprintf( str, "%dx%d", d->video.geom.w, d->video.geom.h );
+    sprintf( str, "%ldx%ld", d->video.geom.w, d->video.geom.h );
     TextValUpdate( Res_text, str );
 
-    sprintf( str, "%d", d->video.fps );
+    sprintf( str, "%ld", d->video.fps );
     TextValUpdate( FPS_text, str );
 
     /*  Set selections based on active format  */
@@ -1988,8 +1977,6 @@ void TVVIDSAVDIALOGNewFrameHdlr( TV_IMAGE *img )
 {
     static long last_time,   /*  FIXME  */
                 last_save_time,
-                sum,
-                frames,
                 in_a_row = 0;
     TV_RAW_IMAGE_HEADER head;
 
@@ -2061,7 +2048,7 @@ void TVVIDSAVDIALOGNewFrameHdlr( TV_IMAGE *img )
             else
                 in_a_row = 0;
 
-            VDPRINTF(( "%4d: Delay = %7d us (Avg = %7d ms, FPS = %2d)%s\n", 
+            VDPRINTF(("%4ld: Delay = %7ld us (Avg = %7ld ms, FPS = %2ld)%s\n", 
                        Vid_stats.frames, diff, 
                        Vid_stats.time_us/Vid_stats.frames/1000, 
                        Vid_stats.frames*1000000L/Vid_stats.time_us,
@@ -2076,9 +2063,9 @@ void TVVIDSAVDIALOGNewFrameHdlr( TV_IMAGE *img )
 
         /*  Read pending audio  */
         if ( Audio_enabled ) {
+#ifdef OLD
             audio_buf_info  info;
 
-#ifdef OLD
             ioctl( Dsp_fd, SNDCTL_DSP_GETISPACE, &info );
             VDPRINTF(( "Bufs = %d / %d, FragSize = %d, TotalBytes = %d\n",
                        info.fragments, info.fragstotal, info.fragsize,
@@ -2171,7 +2158,7 @@ void TVVIDSAVDIALOGRecordStart( TV_INT32 w, TV_INT32 h )
         d->video.geom.w = w;
         d->video.geom.h = h;
         if ( Res_text ) {
-            sprintf( res_str, "%dx%d", w,h );
+            sprintf( res_str, "%ldx%ld", w,h );
             TextValUpdate( Res_text, res_str );
         }
     }
@@ -2211,7 +2198,6 @@ void TVVIDSAVDIALOGRecordStop( void )
     {
         static Atom          xa_FXTV_WAKEUP_NEXTEVENT = None;
         XClientMessageEvent  ev;
-        TV_DISPLAY          *d = &G_glob.display;
 
         if ( xa_FXTV_WAKEUP_NEXTEVENT == None )
             xa_FXTV_WAKEUP_NEXTEVENT = XInternAtom(TVDISPLAY, 
